#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .open_channel import open_channel as open_channel_cls
from .outlet_number import outlet_number as outlet_number_cls
from .pressure_spec_method import pressure_spec_method as pressure_spec_method_cls
from .press_spec import press_spec as press_spec_cls
from .frame_of_reference import frame_of_reference as frame_of_reference_cls
from .phase_spec import phase_spec as phase_spec_cls
from .ht_local import ht_local as ht_local_cls
from .gauge_pressure import gauge_pressure as gauge_pressure_cls
from .p_profile_multiplier import p_profile_multiplier as p_profile_multiplier_cls
from .ht_bottom import ht_bottom as ht_bottom_cls
from .den_spec import den_spec as den_spec_cls
from .t0 import t0 as t0_cls
from .direction_spec import direction_spec as direction_spec_cls
from .coordinate_system import coordinate_system as coordinate_system_cls
from .flow_direction import flow_direction as flow_direction_cls
from .axis_direction_2 import axis_direction as axis_direction_cls
from .axis_origin_2 import axis_origin as axis_origin_cls
from .ke_spec import ke_spec as ke_spec_cls
from .nut import nut as nut_cls
from .kl import kl as kl_cls
from .intermit import intermit as intermit_cls
from .k import k as k_cls
from .e import e as e_cls
from .o import o as o_cls
from .v2 import v2 as v2_cls
from .turb_intensity import turb_intensity as turb_intensity_cls
from .turb_length_scale import turb_length_scale as turb_length_scale_cls
from .turb_hydraulic_diam import turb_hydraulic_diam as turb_hydraulic_diam_cls
from .turb_viscosity_ratio import turb_viscosity_ratio as turb_viscosity_ratio_cls
from .turb_viscosity_ratio_profile import turb_viscosity_ratio_profile as turb_viscosity_ratio_profile_cls
from .rst_spec import rst_spec as rst_spec_cls
from .uu import uu as uu_cls
from .vv import vv as vv_cls
from .ww import ww as ww_cls
from .uv import uv as uv_cls
from .vw import vw as vw_cls
from .uw import uw as uw_cls
from .ksgs_spec import ksgs_spec as ksgs_spec_cls
from .ksgs import ksgs as ksgs_cls
from .sgs_turb_intensity import sgs_turb_intensity as sgs_turb_intensity_cls
from .radiation_bc import radiation_bc as radiation_bc_cls
from .radial_direction import radial_direction as radial_direction_cls
from .coll_dtheta import coll_dtheta as coll_dtheta_cls
from .coll_dphi import coll_dphi as coll_dphi_cls
from .band_q_irrad import band_q_irrad as band_q_irrad_cls
from .band_q_irrad_diffuse import band_q_irrad_diffuse as band_q_irrad_diffuse_cls
from .parallel_collimated_beam import parallel_collimated_beam as parallel_collimated_beam_cls
from .solar_direction import solar_direction as solar_direction_cls
from .solar_irradiation import solar_irradiation as solar_irradiation_cls
from .t_b_b_spec import t_b_b_spec as t_b_b_spec_cls
from .t_b_b import t_b_b as t_b_b_cls
from .in_emiss import in_emiss as in_emiss_cls
from .fmean import fmean as fmean_cls
from .fmean2 import fmean2 as fmean2_cls
from .fvar import fvar as fvar_cls
from .fvar2 import fvar2 as fvar2_cls
from .granular_temperature import granular_temperature as granular_temperature_cls
from .iac import iac as iac_cls
from .lsfun import lsfun as lsfun_cls
from .vof_spec import vof_spec as vof_spec_cls
from .volume_fraction import volume_fraction as volume_fraction_cls
from .species_in_mole_fractions import species_in_mole_fractions as species_in_mole_fractions_cls
from .mf import mf as mf_cls
from .elec_potential_type import elec_potential_type as elec_potential_type_cls
from .potential_value import potential_value as potential_value_cls
from .dual_potential_type import dual_potential_type as dual_potential_type_cls
from .dual_potential_value import dual_potential_value as dual_potential_value_cls
from .x_displacement_type import x_displacement_type as x_displacement_type_cls
from .x_displacement_value import x_displacement_value as x_displacement_value_cls
from .y_displacement_type import y_displacement_type as y_displacement_type_cls
from .y_displacement_value import y_displacement_value as y_displacement_value_cls
from .z_displacement_type import z_displacement_type as z_displacement_type_cls
from .z_displacement_value import z_displacement_value as z_displacement_value_cls
from .prob_mode_1 import prob_mode_1 as prob_mode_1_cls
from .prob_mode_2 import prob_mode_2 as prob_mode_2_cls
from .prob_mode_3 import prob_mode_3 as prob_mode_3_cls
from .premixc import premixc as premixc_cls
from .premixc_var import premixc_var as premixc_var_cls
from .ecfm_sigma import ecfm_sigma as ecfm_sigma_cls
from .inert import inert as inert_cls
from .pollut_no import pollut_no as pollut_no_cls
from .pollut_hcn import pollut_hcn as pollut_hcn_cls
from .pollut_nh3 import pollut_nh3 as pollut_nh3_cls
from .pollut_n2o import pollut_n2o as pollut_n2o_cls
from .pollut_urea import pollut_urea as pollut_urea_cls
from .pollut_hnco import pollut_hnco as pollut_hnco_cls
from .pollut_nco import pollut_nco as pollut_nco_cls
from .pollut_so2 import pollut_so2 as pollut_so2_cls
from .pollut_h2s import pollut_h2s as pollut_h2s_cls
from .pollut_so3 import pollut_so3 as pollut_so3_cls
from .pollut_sh import pollut_sh as pollut_sh_cls
from .pollut_so import pollut_so as pollut_so_cls
from .pollut_soot import pollut_soot as pollut_soot_cls
from .pollut_nuclei import pollut_nuclei as pollut_nuclei_cls
from .pollut_ctar import pollut_ctar as pollut_ctar_cls
from .pollut_hg import pollut_hg as pollut_hg_cls
from .pollut_hgcl2 import pollut_hgcl2 as pollut_hgcl2_cls
from .pollut_hcl import pollut_hcl as pollut_hcl_cls
from .pollut_hgo import pollut_hgo as pollut_hgo_cls
from .pollut_cl import pollut_cl as pollut_cl_cls
from .pollut_cl2 import pollut_cl2 as pollut_cl2_cls
from .pollut_hgcl import pollut_hgcl as pollut_hgcl_cls
from .pollut_hocl import pollut_hocl as pollut_hocl_cls
from .tss_scalar import tss_scalar as tss_scalar_cls
from .fensapice_flow_bc_subtype import fensapice_flow_bc_subtype as fensapice_flow_bc_subtype_cls
from .uds_bc import uds_bc as uds_bc_cls
from .uds import uds as uds_cls
from .pb_disc_bc import pb_disc_bc as pb_disc_bc_cls
from .pb_disc import pb_disc as pb_disc_cls
from .pb_qmom_bc import pb_qmom_bc as pb_qmom_bc_cls
from .pb_qmom import pb_qmom as pb_qmom_cls
from .pb_smm_bc import pb_smm_bc as pb_smm_bc_cls
from .pb_smm import pb_smm as pb_smm_cls
from .pb_dqmom_bc import pb_dqmom_bc as pb_dqmom_bc_cls
from .pb_dqmom import pb_dqmom as pb_dqmom_cls
from .dpm_bc_type import dpm_bc_type as dpm_bc_type_cls
from .dpm_bc_collision_partner import dpm_bc_collision_partner as dpm_bc_collision_partner_cls
from .reinj_inj import reinj_inj as reinj_inj_cls
from .dpm_bc_udf import dpm_bc_udf as dpm_bc_udf_cls
from .mixing_plane_thread import mixing_plane_thread as mixing_plane_thread_cls
from .ac_options import ac_options as ac_options_cls
from .p_backflow_spec import p_backflow_spec as p_backflow_spec_cls
from .p_backflow_spec_gen import p_backflow_spec_gen as p_backflow_spec_gen_cls
from .impedance_0 import impedance_0 as impedance_0_cls
from .impedance_1 import impedance_1 as impedance_1_cls
from .impedance_2 import impedance_2 as impedance_2_cls
from .ac_wave import ac_wave as ac_wave_cls
from .prevent_reverse_flow import prevent_reverse_flow as prevent_reverse_flow_cls
from .radial import radial as radial_cls
from .avg_press_spec import avg_press_spec as avg_press_spec_cls
from .press_averaging_method import press_averaging_method as press_averaging_method_cls
from .targeted_mf_boundary import targeted_mf_boundary as targeted_mf_boundary_cls
from .targeted_mf import targeted_mf as targeted_mf_cls
from .targeted_mf_pmax import targeted_mf_pmax as targeted_mf_pmax_cls
from .targeted_mf_pmin import targeted_mf_pmin as targeted_mf_pmin_cls
from .gen_nrbc_spec import gen_nrbc_spec as gen_nrbc_spec_cls
from .wsf import wsf as wsf_cls
from .wsb import wsb as wsb_cls
from .wsn import wsn as wsn_cls
from .solar_fluxes import solar_fluxes as solar_fluxes_cls
from .solar_shining_factor import solar_shining_factor as solar_shining_factor_cls
from .radiating_s2s_surface import radiating_s2s_surface as radiating_s2s_surface_cls
from .b_1 import b as b_cls
from .strength import strength as strength_cls
class phase_child(Group):
    """
    'child_object_type' of phase.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['geom_disable', 'geom_dir_spec', 'geom_dir_x', 'geom_dir_y',
         'geom_dir_z', 'geom_levels', 'geom_bgthread', 'open_channel',
         'outlet_number', 'pressure_spec_method', 'press_spec',
         'frame_of_reference', 'phase_spec', 'ht_local', 'gauge_pressure',
         'p_profile_multiplier', 'ht_bottom', 'den_spec', 't0',
         'direction_spec', 'coordinate_system', 'flow_direction',
         'axis_direction', 'axis_origin', 'ke_spec', 'nut', 'kl', 'intermit',
         'k', 'e', 'o', 'v2', 'turb_intensity', 'turb_length_scale',
         'turb_hydraulic_diam', 'turb_viscosity_ratio',
         'turb_viscosity_ratio_profile', 'rst_spec', 'uu', 'vv', 'ww', 'uv',
         'vw', 'uw', 'ksgs_spec', 'ksgs', 'sgs_turb_intensity',
         'radiation_bc', 'radial_direction', 'coll_dtheta', 'coll_dphi',
         'band_q_irrad', 'band_q_irrad_diffuse', 'parallel_collimated_beam',
         'solar_direction', 'solar_irradiation', 't_b_b_spec', 't_b_b',
         'in_emiss', 'fmean', 'fmean2', 'fvar', 'fvar2',
         'granular_temperature', 'iac', 'lsfun', 'vof_spec',
         'volume_fraction', 'species_in_mole_fractions', 'mf',
         'elec_potential_type', 'potential_value', 'dual_potential_type',
         'dual_potential_value', 'x_displacement_type',
         'x_displacement_value', 'y_displacement_type',
         'y_displacement_value', 'z_displacement_type',
         'z_displacement_value', 'prob_mode_1', 'prob_mode_2', 'prob_mode_3',
         'premixc', 'premixc_var', 'ecfm_sigma', 'inert', 'pollut_no',
         'pollut_hcn', 'pollut_nh3', 'pollut_n2o', 'pollut_urea',
         'pollut_hnco', 'pollut_nco', 'pollut_so2', 'pollut_h2s',
         'pollut_so3', 'pollut_sh', 'pollut_so', 'pollut_soot',
         'pollut_nuclei', 'pollut_ctar', 'pollut_hg', 'pollut_hgcl2',
         'pollut_hcl', 'pollut_hgo', 'pollut_cl', 'pollut_cl2', 'pollut_hgcl',
         'pollut_hocl', 'tss_scalar', 'fensapice_flow_bc_subtype', 'uds_bc',
         'uds', 'pb_disc_bc', 'pb_disc', 'pb_qmom_bc', 'pb_qmom', 'pb_smm_bc',
         'pb_smm', 'pb_dqmom_bc', 'pb_dqmom', 'dpm_bc_type',
         'dpm_bc_collision_partner', 'reinj_inj', 'dpm_bc_udf',
         'mixing_plane_thread', 'ac_options', 'p_backflow_spec',
         'p_backflow_spec_gen', 'impedance_0', 'impedance_1', 'impedance_2',
         'ac_wave', 'prevent_reverse_flow', 'radial', 'avg_press_spec',
         'press_averaging_method', 'targeted_mf_boundary', 'targeted_mf',
         'targeted_mf_pmax', 'targeted_mf_pmin', 'gen_nrbc_spec', 'wsf',
         'wsb', 'wsn', 'solar_fluxes', 'solar_shining_factor',
         'radiating_s2s_surface', 'b', 'strength']

    geom_disable: geom_disable_cls = geom_disable_cls
    """
    geom_disable child of phase_child.
    """
    geom_dir_spec: geom_dir_spec_cls = geom_dir_spec_cls
    """
    geom_dir_spec child of phase_child.
    """
    geom_dir_x: geom_dir_x_cls = geom_dir_x_cls
    """
    geom_dir_x child of phase_child.
    """
    geom_dir_y: geom_dir_y_cls = geom_dir_y_cls
    """
    geom_dir_y child of phase_child.
    """
    geom_dir_z: geom_dir_z_cls = geom_dir_z_cls
    """
    geom_dir_z child of phase_child.
    """
    geom_levels: geom_levels_cls = geom_levels_cls
    """
    geom_levels child of phase_child.
    """
    geom_bgthread: geom_bgthread_cls = geom_bgthread_cls
    """
    geom_bgthread child of phase_child.
    """
    open_channel: open_channel_cls = open_channel_cls
    """
    open_channel child of phase_child.
    """
    outlet_number: outlet_number_cls = outlet_number_cls
    """
    outlet_number child of phase_child.
    """
    pressure_spec_method: pressure_spec_method_cls = pressure_spec_method_cls
    """
    pressure_spec_method child of phase_child.
    """
    press_spec: press_spec_cls = press_spec_cls
    """
    press_spec child of phase_child.
    """
    frame_of_reference: frame_of_reference_cls = frame_of_reference_cls
    """
    frame_of_reference child of phase_child.
    """
    phase_spec: phase_spec_cls = phase_spec_cls
    """
    phase_spec child of phase_child.
    """
    ht_local: ht_local_cls = ht_local_cls
    """
    ht_local child of phase_child.
    """
    gauge_pressure: gauge_pressure_cls = gauge_pressure_cls
    """
    gauge_pressure child of phase_child.
    """
    p_profile_multiplier: p_profile_multiplier_cls = p_profile_multiplier_cls
    """
    p_profile_multiplier child of phase_child.
    """
    ht_bottom: ht_bottom_cls = ht_bottom_cls
    """
    ht_bottom child of phase_child.
    """
    den_spec: den_spec_cls = den_spec_cls
    """
    den_spec child of phase_child.
    """
    t0: t0_cls = t0_cls
    """
    t0 child of phase_child.
    """
    direction_spec: direction_spec_cls = direction_spec_cls
    """
    direction_spec child of phase_child.
    """
    coordinate_system: coordinate_system_cls = coordinate_system_cls
    """
    coordinate_system child of phase_child.
    """
    flow_direction: flow_direction_cls = flow_direction_cls
    """
    flow_direction child of phase_child.
    """
    axis_direction: axis_direction_cls = axis_direction_cls
    """
    axis_direction child of phase_child.
    """
    axis_origin: axis_origin_cls = axis_origin_cls
    """
    axis_origin child of phase_child.
    """
    ke_spec: ke_spec_cls = ke_spec_cls
    """
    ke_spec child of phase_child.
    """
    nut: nut_cls = nut_cls
    """
    nut child of phase_child.
    """
    kl: kl_cls = kl_cls
    """
    kl child of phase_child.
    """
    intermit: intermit_cls = intermit_cls
    """
    intermit child of phase_child.
    """
    k: k_cls = k_cls
    """
    k child of phase_child.
    """
    e: e_cls = e_cls
    """
    e child of phase_child.
    """
    o: o_cls = o_cls
    """
    o child of phase_child.
    """
    v2: v2_cls = v2_cls
    """
    v2 child of phase_child.
    """
    turb_intensity: turb_intensity_cls = turb_intensity_cls
    """
    turb_intensity child of phase_child.
    """
    turb_length_scale: turb_length_scale_cls = turb_length_scale_cls
    """
    turb_length_scale child of phase_child.
    """
    turb_hydraulic_diam: turb_hydraulic_diam_cls = turb_hydraulic_diam_cls
    """
    turb_hydraulic_diam child of phase_child.
    """
    turb_viscosity_ratio: turb_viscosity_ratio_cls = turb_viscosity_ratio_cls
    """
    turb_viscosity_ratio child of phase_child.
    """
    turb_viscosity_ratio_profile: turb_viscosity_ratio_profile_cls = turb_viscosity_ratio_profile_cls
    """
    turb_viscosity_ratio_profile child of phase_child.
    """
    rst_spec: rst_spec_cls = rst_spec_cls
    """
    rst_spec child of phase_child.
    """
    uu: uu_cls = uu_cls
    """
    uu child of phase_child.
    """
    vv: vv_cls = vv_cls
    """
    vv child of phase_child.
    """
    ww: ww_cls = ww_cls
    """
    ww child of phase_child.
    """
    uv: uv_cls = uv_cls
    """
    uv child of phase_child.
    """
    vw: vw_cls = vw_cls
    """
    vw child of phase_child.
    """
    uw: uw_cls = uw_cls
    """
    uw child of phase_child.
    """
    ksgs_spec: ksgs_spec_cls = ksgs_spec_cls
    """
    ksgs_spec child of phase_child.
    """
    ksgs: ksgs_cls = ksgs_cls
    """
    ksgs child of phase_child.
    """
    sgs_turb_intensity: sgs_turb_intensity_cls = sgs_turb_intensity_cls
    """
    sgs_turb_intensity child of phase_child.
    """
    radiation_bc: radiation_bc_cls = radiation_bc_cls
    """
    radiation_bc child of phase_child.
    """
    radial_direction: radial_direction_cls = radial_direction_cls
    """
    radial_direction child of phase_child.
    """
    coll_dtheta: coll_dtheta_cls = coll_dtheta_cls
    """
    coll_dtheta child of phase_child.
    """
    coll_dphi: coll_dphi_cls = coll_dphi_cls
    """
    coll_dphi child of phase_child.
    """
    band_q_irrad: band_q_irrad_cls = band_q_irrad_cls
    """
    band_q_irrad child of phase_child.
    """
    band_q_irrad_diffuse: band_q_irrad_diffuse_cls = band_q_irrad_diffuse_cls
    """
    band_q_irrad_diffuse child of phase_child.
    """
    parallel_collimated_beam: parallel_collimated_beam_cls = parallel_collimated_beam_cls
    """
    parallel_collimated_beam child of phase_child.
    """
    solar_direction: solar_direction_cls = solar_direction_cls
    """
    solar_direction child of phase_child.
    """
    solar_irradiation: solar_irradiation_cls = solar_irradiation_cls
    """
    solar_irradiation child of phase_child.
    """
    t_b_b_spec: t_b_b_spec_cls = t_b_b_spec_cls
    """
    t_b_b_spec child of phase_child.
    """
    t_b_b: t_b_b_cls = t_b_b_cls
    """
    t_b_b child of phase_child.
    """
    in_emiss: in_emiss_cls = in_emiss_cls
    """
    in_emiss child of phase_child.
    """
    fmean: fmean_cls = fmean_cls
    """
    fmean child of phase_child.
    """
    fmean2: fmean2_cls = fmean2_cls
    """
    fmean2 child of phase_child.
    """
    fvar: fvar_cls = fvar_cls
    """
    fvar child of phase_child.
    """
    fvar2: fvar2_cls = fvar2_cls
    """
    fvar2 child of phase_child.
    """
    granular_temperature: granular_temperature_cls = granular_temperature_cls
    """
    granular_temperature child of phase_child.
    """
    iac: iac_cls = iac_cls
    """
    iac child of phase_child.
    """
    lsfun: lsfun_cls = lsfun_cls
    """
    lsfun child of phase_child.
    """
    vof_spec: vof_spec_cls = vof_spec_cls
    """
    vof_spec child of phase_child.
    """
    volume_fraction: volume_fraction_cls = volume_fraction_cls
    """
    volume_fraction child of phase_child.
    """
    species_in_mole_fractions: species_in_mole_fractions_cls = species_in_mole_fractions_cls
    """
    species_in_mole_fractions child of phase_child.
    """
    mf: mf_cls = mf_cls
    """
    mf child of phase_child.
    """
    elec_potential_type: elec_potential_type_cls = elec_potential_type_cls
    """
    elec_potential_type child of phase_child.
    """
    potential_value: potential_value_cls = potential_value_cls
    """
    potential_value child of phase_child.
    """
    dual_potential_type: dual_potential_type_cls = dual_potential_type_cls
    """
    dual_potential_type child of phase_child.
    """
    dual_potential_value: dual_potential_value_cls = dual_potential_value_cls
    """
    dual_potential_value child of phase_child.
    """
    x_displacement_type: x_displacement_type_cls = x_displacement_type_cls
    """
    x_displacement_type child of phase_child.
    """
    x_displacement_value: x_displacement_value_cls = x_displacement_value_cls
    """
    x_displacement_value child of phase_child.
    """
    y_displacement_type: y_displacement_type_cls = y_displacement_type_cls
    """
    y_displacement_type child of phase_child.
    """
    y_displacement_value: y_displacement_value_cls = y_displacement_value_cls
    """
    y_displacement_value child of phase_child.
    """
    z_displacement_type: z_displacement_type_cls = z_displacement_type_cls
    """
    z_displacement_type child of phase_child.
    """
    z_displacement_value: z_displacement_value_cls = z_displacement_value_cls
    """
    z_displacement_value child of phase_child.
    """
    prob_mode_1: prob_mode_1_cls = prob_mode_1_cls
    """
    prob_mode_1 child of phase_child.
    """
    prob_mode_2: prob_mode_2_cls = prob_mode_2_cls
    """
    prob_mode_2 child of phase_child.
    """
    prob_mode_3: prob_mode_3_cls = prob_mode_3_cls
    """
    prob_mode_3 child of phase_child.
    """
    premixc: premixc_cls = premixc_cls
    """
    premixc child of phase_child.
    """
    premixc_var: premixc_var_cls = premixc_var_cls
    """
    premixc_var child of phase_child.
    """
    ecfm_sigma: ecfm_sigma_cls = ecfm_sigma_cls
    """
    ecfm_sigma child of phase_child.
    """
    inert: inert_cls = inert_cls
    """
    inert child of phase_child.
    """
    pollut_no: pollut_no_cls = pollut_no_cls
    """
    pollut_no child of phase_child.
    """
    pollut_hcn: pollut_hcn_cls = pollut_hcn_cls
    """
    pollut_hcn child of phase_child.
    """
    pollut_nh3: pollut_nh3_cls = pollut_nh3_cls
    """
    pollut_nh3 child of phase_child.
    """
    pollut_n2o: pollut_n2o_cls = pollut_n2o_cls
    """
    pollut_n2o child of phase_child.
    """
    pollut_urea: pollut_urea_cls = pollut_urea_cls
    """
    pollut_urea child of phase_child.
    """
    pollut_hnco: pollut_hnco_cls = pollut_hnco_cls
    """
    pollut_hnco child of phase_child.
    """
    pollut_nco: pollut_nco_cls = pollut_nco_cls
    """
    pollut_nco child of phase_child.
    """
    pollut_so2: pollut_so2_cls = pollut_so2_cls
    """
    pollut_so2 child of phase_child.
    """
    pollut_h2s: pollut_h2s_cls = pollut_h2s_cls
    """
    pollut_h2s child of phase_child.
    """
    pollut_so3: pollut_so3_cls = pollut_so3_cls
    """
    pollut_so3 child of phase_child.
    """
    pollut_sh: pollut_sh_cls = pollut_sh_cls
    """
    pollut_sh child of phase_child.
    """
    pollut_so: pollut_so_cls = pollut_so_cls
    """
    pollut_so child of phase_child.
    """
    pollut_soot: pollut_soot_cls = pollut_soot_cls
    """
    pollut_soot child of phase_child.
    """
    pollut_nuclei: pollut_nuclei_cls = pollut_nuclei_cls
    """
    pollut_nuclei child of phase_child.
    """
    pollut_ctar: pollut_ctar_cls = pollut_ctar_cls
    """
    pollut_ctar child of phase_child.
    """
    pollut_hg: pollut_hg_cls = pollut_hg_cls
    """
    pollut_hg child of phase_child.
    """
    pollut_hgcl2: pollut_hgcl2_cls = pollut_hgcl2_cls
    """
    pollut_hgcl2 child of phase_child.
    """
    pollut_hcl: pollut_hcl_cls = pollut_hcl_cls
    """
    pollut_hcl child of phase_child.
    """
    pollut_hgo: pollut_hgo_cls = pollut_hgo_cls
    """
    pollut_hgo child of phase_child.
    """
    pollut_cl: pollut_cl_cls = pollut_cl_cls
    """
    pollut_cl child of phase_child.
    """
    pollut_cl2: pollut_cl2_cls = pollut_cl2_cls
    """
    pollut_cl2 child of phase_child.
    """
    pollut_hgcl: pollut_hgcl_cls = pollut_hgcl_cls
    """
    pollut_hgcl child of phase_child.
    """
    pollut_hocl: pollut_hocl_cls = pollut_hocl_cls
    """
    pollut_hocl child of phase_child.
    """
    tss_scalar: tss_scalar_cls = tss_scalar_cls
    """
    tss_scalar child of phase_child.
    """
    fensapice_flow_bc_subtype: fensapice_flow_bc_subtype_cls = fensapice_flow_bc_subtype_cls
    """
    fensapice_flow_bc_subtype child of phase_child.
    """
    uds_bc: uds_bc_cls = uds_bc_cls
    """
    uds_bc child of phase_child.
    """
    uds: uds_cls = uds_cls
    """
    uds child of phase_child.
    """
    pb_disc_bc: pb_disc_bc_cls = pb_disc_bc_cls
    """
    pb_disc_bc child of phase_child.
    """
    pb_disc: pb_disc_cls = pb_disc_cls
    """
    pb_disc child of phase_child.
    """
    pb_qmom_bc: pb_qmom_bc_cls = pb_qmom_bc_cls
    """
    pb_qmom_bc child of phase_child.
    """
    pb_qmom: pb_qmom_cls = pb_qmom_cls
    """
    pb_qmom child of phase_child.
    """
    pb_smm_bc: pb_smm_bc_cls = pb_smm_bc_cls
    """
    pb_smm_bc child of phase_child.
    """
    pb_smm: pb_smm_cls = pb_smm_cls
    """
    pb_smm child of phase_child.
    """
    pb_dqmom_bc: pb_dqmom_bc_cls = pb_dqmom_bc_cls
    """
    pb_dqmom_bc child of phase_child.
    """
    pb_dqmom: pb_dqmom_cls = pb_dqmom_cls
    """
    pb_dqmom child of phase_child.
    """
    dpm_bc_type: dpm_bc_type_cls = dpm_bc_type_cls
    """
    dpm_bc_type child of phase_child.
    """
    dpm_bc_collision_partner: dpm_bc_collision_partner_cls = dpm_bc_collision_partner_cls
    """
    dpm_bc_collision_partner child of phase_child.
    """
    reinj_inj: reinj_inj_cls = reinj_inj_cls
    """
    reinj_inj child of phase_child.
    """
    dpm_bc_udf: dpm_bc_udf_cls = dpm_bc_udf_cls
    """
    dpm_bc_udf child of phase_child.
    """
    mixing_plane_thread: mixing_plane_thread_cls = mixing_plane_thread_cls
    """
    mixing_plane_thread child of phase_child.
    """
    ac_options: ac_options_cls = ac_options_cls
    """
    ac_options child of phase_child.
    """
    p_backflow_spec: p_backflow_spec_cls = p_backflow_spec_cls
    """
    p_backflow_spec child of phase_child.
    """
    p_backflow_spec_gen: p_backflow_spec_gen_cls = p_backflow_spec_gen_cls
    """
    p_backflow_spec_gen child of phase_child.
    """
    impedance_0: impedance_0_cls = impedance_0_cls
    """
    impedance_0 child of phase_child.
    """
    impedance_1: impedance_1_cls = impedance_1_cls
    """
    impedance_1 child of phase_child.
    """
    impedance_2: impedance_2_cls = impedance_2_cls
    """
    impedance_2 child of phase_child.
    """
    ac_wave: ac_wave_cls = ac_wave_cls
    """
    ac_wave child of phase_child.
    """
    prevent_reverse_flow: prevent_reverse_flow_cls = prevent_reverse_flow_cls
    """
    prevent_reverse_flow child of phase_child.
    """
    radial: radial_cls = radial_cls
    """
    radial child of phase_child.
    """
    avg_press_spec: avg_press_spec_cls = avg_press_spec_cls
    """
    avg_press_spec child of phase_child.
    """
    press_averaging_method: press_averaging_method_cls = press_averaging_method_cls
    """
    press_averaging_method child of phase_child.
    """
    targeted_mf_boundary: targeted_mf_boundary_cls = targeted_mf_boundary_cls
    """
    targeted_mf_boundary child of phase_child.
    """
    targeted_mf: targeted_mf_cls = targeted_mf_cls
    """
    targeted_mf child of phase_child.
    """
    targeted_mf_pmax: targeted_mf_pmax_cls = targeted_mf_pmax_cls
    """
    targeted_mf_pmax child of phase_child.
    """
    targeted_mf_pmin: targeted_mf_pmin_cls = targeted_mf_pmin_cls
    """
    targeted_mf_pmin child of phase_child.
    """
    gen_nrbc_spec: gen_nrbc_spec_cls = gen_nrbc_spec_cls
    """
    gen_nrbc_spec child of phase_child.
    """
    wsf: wsf_cls = wsf_cls
    """
    wsf child of phase_child.
    """
    wsb: wsb_cls = wsb_cls
    """
    wsb child of phase_child.
    """
    wsn: wsn_cls = wsn_cls
    """
    wsn child of phase_child.
    """
    solar_fluxes: solar_fluxes_cls = solar_fluxes_cls
    """
    solar_fluxes child of phase_child.
    """
    solar_shining_factor: solar_shining_factor_cls = solar_shining_factor_cls
    """
    solar_shining_factor child of phase_child.
    """
    radiating_s2s_surface: radiating_s2s_surface_cls = radiating_s2s_surface_cls
    """
    radiating_s2s_surface child of phase_child.
    """
    b: b_cls = b_cls
    """
    b child of phase_child.
    """
    strength: strength_cls = strength_cls
    """
    strength child of phase_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class colors:
    fluent_name = ...
    child_names = ...
    background = ...
    color_by_type = ...
    foreground = ...
    by_type = ...
    by_surface = ...
    far_field_faces = ...
    inlet_faces = ...
    interior_faces = ...
    internal_faces = ...
    outlet_faces = ...
    overset_faces = ...
    periodic_faces = ...
    rans_les_interface_faces = ...
    symmetry_faces = ...
    axis_faces = ...
    free_surface_faces = ...
    traction_faces = ...
    wall_faces = ...
    interface_faces = ...
    surface = ...
    skip_label = ...
    automatic_skip = ...
    command_names = ...

    def reset_colors(self, ):
        """
        Reset individual mesh surface colors to the defaults.
        """

    def list_colors(self, ):
        """
        List available colors.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .value1 import value1 as value1_cls
from .value2 import value2 as value2_cls
class in_range(Group):
    """
    'in_range' child.
    """

    fluent_name = "in-range"

    child_names = \
        ['value1', 'value2']

    value1: value1_cls = value1_cls
    """
    value1 child of in_range.
    """
    value2: value2_cls = value2_cls
    """
    value2 child of in_range.
    """



import time

from util.solver_workflow import new_solver_session  # noqa: F401

from ansys.fluent.core import connect_to_fluent


def transcript(data):
    transcript.data = data


def run_transcript(i, ip, port, password):
    transcript("")
    session = connect_to_fluent(
        ip=ip, port=port, password=password, cleanup_on_exit=False
    )
    session.transcript.register_callback(transcript)

    transcript_checked = False
    transcript_passed = False

    if i % 5 == 0:
        time.sleep(0.5)
        session.scheme_eval.scheme_eval("(pp 'test)")
        time.sleep(0.5)
        if not transcript.data:
            assert transcript.data == ""
        else:
            assert transcript.data == "test"
            transcript_passed = True
        transcript_checked = True

    return transcript_checked, transcript_passed


def test_transcript(new_solver_session):
    solver = new_solver_session
    ip = solver.connection_properties.ip
    port = solver.connection_properties.port
    password = solver.connection_properties.password

    total_checked_transcripts = 0
    total_passed_transcripts = 0

    for i in range(100):
        transcript_checked, transcript_passed = run_transcript(i, ip, port, password)
        total_checked_transcripts += int(transcript_checked)
        total_passed_transcripts += int(transcript_passed)

    if solver.get_fluent_version() >= "23.2.0":
        assert total_checked_transcripts == total_passed_transcripts
    else:
        assert total_checked_transcripts >= total_passed_transcripts



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .auto_1 import auto as auto_cls
from .set_3 import set as set_cls
from .combine_partition import combine_partition as combine_partition_cls
from .merge_clusters import merge_clusters as merge_clusters_cls
from .method_10 import method as method_cls
from .print_partitions import print_partitions as print_partitions_cls
from .print_active_partitions import print_active_partitions as print_active_partitions_cls
from .print_stored_partitions import print_stored_partitions as print_stored_partitions_cls
from .reorder_partitions import reorder_partitions as reorder_partitions_cls
from .reorder_partitions_to_architecture import reorder_partitions_to_architecture as reorder_partitions_to_architecture_cls
from .smooth_partition import smooth_partition as smooth_partition_cls
from .use_stored_partitions import use_stored_partitions as use_stored_partitions_cls
class partition(Group):
    """
    Enter the partition domain menu.
    """

    fluent_name = "partition"

    child_names = \
        ['auto', 'set']

    auto: auto_cls = auto_cls
    """
    auto child of partition.
    """
    set: set_cls = set_cls
    """
    set child of partition.
    """
    command_names = \
        ['combine_partition', 'merge_clusters', 'method', 'print_partitions',
         'print_active_partitions', 'print_stored_partitions',
         'reorder_partitions', 'reorder_partitions_to_architecture',
         'smooth_partition', 'use_stored_partitions']

    combine_partition: combine_partition_cls = combine_partition_cls
    """
    combine_partition command of partition.
    """
    merge_clusters: merge_clusters_cls = merge_clusters_cls
    """
    merge_clusters command of partition.
    """
    method: method_cls = method_cls
    """
    method command of partition.
    """
    print_partitions: print_partitions_cls = print_partitions_cls
    """
    print_partitions command of partition.
    """
    print_active_partitions: print_active_partitions_cls = print_active_partitions_cls
    """
    print_active_partitions command of partition.
    """
    print_stored_partitions: print_stored_partitions_cls = print_stored_partitions_cls
    """
    print_stored_partitions command of partition.
    """
    reorder_partitions: reorder_partitions_cls = reorder_partitions_cls
    """
    reorder_partitions command of partition.
    """
    reorder_partitions_to_architecture: reorder_partitions_to_architecture_cls = reorder_partitions_to_architecture_cls
    """
    reorder_partitions_to_architecture command of partition.
    """
    smooth_partition: smooth_partition_cls = smooth_partition_cls
    """
    smooth_partition command of partition.
    """
    use_stored_partitions: use_stored_partitions_cls = use_stored_partitions_cls
    """
    use_stored_partitions command of partition.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class convert_hanging_node_zones(Command):
    """
    Convert selected cell zones with hanging nodes and faces to polyhedra. 
    The selected cell zones cannot be connected to other zones.
    """

    fluent_name = "convert-hanging-node-zones"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option import option as option_cls
from .function_of import function_of as function_of_cls
from .value_4 import value as value_cls
from .piecewise_polynomial import piecewise_polynomial as piecewise_polynomial_cls
from .piecewise_linear_1 import piecewise_linear as piecewise_linear_cls
from .polynomial_1 import polynomial as polynomial_cls
class dpm_bc_norm_coeff(Group):
    """
    Normal .
    """

    fluent_name = "dpm-bc-norm-coeff"

    child_names = \
        ['option', 'function_of', 'value', 'piecewise_polynomial',
         'piecewise_linear', 'polynomial']

    option: option_cls = option_cls
    """
    option child of dpm_bc_norm_coeff.
    """
    function_of: function_of_cls = function_of_cls
    """
    function_of child of dpm_bc_norm_coeff.
    """
    value: value_cls = value_cls
    """
    value child of dpm_bc_norm_coeff.
    """
    piecewise_polynomial: piecewise_polynomial_cls = piecewise_polynomial_cls
    """
    piecewise_polynomial child of dpm_bc_norm_coeff.
    """
    piecewise_linear: piecewise_linear_cls = piecewise_linear_cls
    """
    piecewise_linear child of dpm_bc_norm_coeff.
    """
    polynomial: polynomial_cls = polynomial_cls
    """
    polynomial child of dpm_bc_norm_coeff.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .delete_1 import delete as delete_cls
from .list import list as list_cls
from .list_properties_1 import list_properties as list_properties_cls
from .make_a_copy import make_a_copy as make_a_copy_cls
from .recirculation_inlet_child import recirculation_inlet_child

class recirculation_inlet(NamedObject[recirculation_inlet_child], _NonCreatableNamedObjectMixin[recirculation_inlet_child]):
    """
    'recirculation_inlet' child.
    """

    fluent_name = "recirculation-inlet"

    command_names = \
        ['delete', 'list', 'list_properties', 'make_a_copy']

    delete: delete_cls = delete_cls
    """
    delete command of recirculation_inlet.
    """
    list: list_cls = list_cls
    """
    list command of recirculation_inlet.
    """
    list_properties: list_properties_cls = list_properties_cls
    """
    list_properties command of recirculation_inlet.
    """
    make_a_copy: make_a_copy_cls = make_a_copy_cls
    """
    make_a_copy command of recirculation_inlet.
    """
    child_object_type: recirculation_inlet_child = recirculation_inlet_child
    """
    child_object_type of recirculation_inlet.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name import name as name_cls
from .chemical_formula import chemical_formula as chemical_formula_cls
from .density_1 import density as density_cls
from .specific_heat_1 import specific_heat as specific_heat_cls
from .thermal_conductivity_1 import thermal_conductivity as thermal_conductivity_cls
from .atomic_number import atomic_number as atomic_number_cls
from .absorption_coefficient import absorption_coefficient as absorption_coefficient_cls
from .scattering_coefficient_1 import scattering_coefficient as scattering_coefficient_cls
from .scattering_phase_function import scattering_phase_function as scattering_phase_function_cls
from .refractive_index import refractive_index as refractive_index_cls
from .uds_diffusivity_1 import uds_diffusivity as uds_diffusivity_cls
from .electric_conductivity import electric_conductivity as electric_conductivity_cls
from .dual_electric_conductivity import dual_electric_conductivity as dual_electric_conductivity_cls
from .lithium_diffusivity import lithium_diffusivity as lithium_diffusivity_cls
from .magnetic_permeability import magnetic_permeability as magnetic_permeability_cls
from .struct_youngs_modulus import struct_youngs_modulus as struct_youngs_modulus_cls
from .struct_poisson_ratio import struct_poisson_ratio as struct_poisson_ratio_cls
from .struct_start_temperature import struct_start_temperature as struct_start_temperature_cls
from .struct_thermal_expansion import struct_thermal_expansion as struct_thermal_expansion_cls
from .struct_damping_alpha import struct_damping_alpha as struct_damping_alpha_cls
from .struct_damping_beta import struct_damping_beta as struct_damping_beta_cls
class solid_child(Group):
    """
    'child_object_type' of solid.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'chemical_formula', 'density', 'specific_heat',
         'thermal_conductivity', 'atomic_number', 'absorption_coefficient',
         'scattering_coefficient', 'scattering_phase_function',
         'refractive_index', 'uds_diffusivity', 'electric_conductivity',
         'dual_electric_conductivity', 'lithium_diffusivity',
         'magnetic_permeability', 'struct_youngs_modulus',
         'struct_poisson_ratio', 'struct_start_temperature',
         'struct_thermal_expansion', 'struct_damping_alpha',
         'struct_damping_beta']

    name: name_cls = name_cls
    """
    name child of solid_child.
    """
    chemical_formula: chemical_formula_cls = chemical_formula_cls
    """
    chemical_formula child of solid_child.
    """
    density: density_cls = density_cls
    """
    density child of solid_child.
    """
    specific_heat: specific_heat_cls = specific_heat_cls
    """
    specific_heat child of solid_child.
    """
    thermal_conductivity: thermal_conductivity_cls = thermal_conductivity_cls
    """
    thermal_conductivity child of solid_child.
    """
    atomic_number: atomic_number_cls = atomic_number_cls
    """
    atomic_number child of solid_child.
    """
    absorption_coefficient: absorption_coefficient_cls = absorption_coefficient_cls
    """
    absorption_coefficient child of solid_child.
    """
    scattering_coefficient: scattering_coefficient_cls = scattering_coefficient_cls
    """
    scattering_coefficient child of solid_child.
    """
    scattering_phase_function: scattering_phase_function_cls = scattering_phase_function_cls
    """
    scattering_phase_function child of solid_child.
    """
    refractive_index: refractive_index_cls = refractive_index_cls
    """
    refractive_index child of solid_child.
    """
    uds_diffusivity: uds_diffusivity_cls = uds_diffusivity_cls
    """
    uds_diffusivity child of solid_child.
    """
    electric_conductivity: electric_conductivity_cls = electric_conductivity_cls
    """
    electric_conductivity child of solid_child.
    """
    dual_electric_conductivity: dual_electric_conductivity_cls = dual_electric_conductivity_cls
    """
    dual_electric_conductivity child of solid_child.
    """
    lithium_diffusivity: lithium_diffusivity_cls = lithium_diffusivity_cls
    """
    lithium_diffusivity child of solid_child.
    """
    magnetic_permeability: magnetic_permeability_cls = magnetic_permeability_cls
    """
    magnetic_permeability child of solid_child.
    """
    struct_youngs_modulus: struct_youngs_modulus_cls = struct_youngs_modulus_cls
    """
    struct_youngs_modulus child of solid_child.
    """
    struct_poisson_ratio: struct_poisson_ratio_cls = struct_poisson_ratio_cls
    """
    struct_poisson_ratio child of solid_child.
    """
    struct_start_temperature: struct_start_temperature_cls = struct_start_temperature_cls
    """
    struct_start_temperature child of solid_child.
    """
    struct_thermal_expansion: struct_thermal_expansion_cls = struct_thermal_expansion_cls
    """
    struct_thermal_expansion child of solid_child.
    """
    struct_damping_alpha: struct_damping_alpha_cls = struct_damping_alpha_cls
    """
    struct_damping_alpha child of solid_child.
    """
    struct_damping_beta: struct_damping_beta_cls = struct_damping_beta_cls
    """
    struct_damping_beta child of solid_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .multi_grid_controls_child import multi_grid_controls_child

class multi_grid_controls(NamedObject[multi_grid_controls_child], _CreatableNamedObjectMixin[multi_grid_controls_child]):
    """
    'multi_grid_controls' child.
    """

    fluent_name = "multi-grid-controls"

    child_object_type: multi_grid_controls_child = multi_grid_controls_child
    """
    child_object_type of multi_grid_controls.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .zone_list import zone_list as zone_list_cls
from .new_type import new_type as new_type_cls
class set_zone_type(Command):
    """
    'set_zone_type' command.
    
    Parameters
    ----------
        zone_list : typing.List[str]
            Enter zone name list.
        new_type : str
            'new_type' child.
    
    """

    fluent_name = "set-zone-type"

    argument_names = \
        ['zone_list', 'new_type']

    zone_list: zone_list_cls = zone_list_cls
    """
    zone_list argument of set_zone_type.
    """
    new_type: new_type_cls = new_type_cls
    """
    new_type argument of set_zone_type.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .acd import acd as acd_cls
from .cd import cd as cd_cls
from .direction_2 import direction as direction_cls
from .angle_1 import angle as angle_cls
class dynamic_injection_child(Group):
    """
    'child_object_type' of dynamic_injection.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['acd', 'cd', 'direction', 'angle']

    acd: acd_cls = acd_cls
    """
    acd child of dynamic_injection_child.
    """
    cd: cd_cls = cd_cls
    """
    cd child of dynamic_injection_child.
    """
    direction: direction_cls = direction_cls
    """
    direction child of dynamic_injection_child.
    """
    angle: angle_cls = angle_cls
    """
    angle child of dynamic_injection_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class reorder_zones(Command):
    """
    Reorder zones by partition, type, and id.
    """

    fluent_name = "reorder-zones"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name_1 import name as name_cls
from .uid import uid as uid_cls
from .options_6 import options as options_cls
from .range import range as range_cls
from .style_attribute import style_attribute as style_attribute_cls
from .accuracy_control_1 import accuracy_control as accuracy_control_cls
from .plot_1 import plot as plot_cls
from .step import step as step_cls
from .skip import skip as skip_cls
from .coarsen import coarsen as coarsen_cls
from .onzone import onzone as onzone_cls
from .onphysics import onphysics as onphysics_cls
from .field import field as field_cls
from .surfaces_list import surfaces_list as surfaces_list_cls
from .velocity_domain import velocity_domain as velocity_domain_cls
from .color_map import color_map as color_map_cls
from .draw_mesh import draw_mesh as draw_mesh_cls
from .mesh_object import mesh_object as mesh_object_cls
from .display_state_name import display_state_name as display_state_name_cls
from .physics import physics as physics_cls
from .geometry_3 import geometry as geometry_cls
from .surfaces import surfaces as surfaces_cls
from .axes import axes as axes_cls
from .curves import curves as curves_cls
from .display_2 import display as display_cls
class pathline_child(Group):
    """
    'child_object_type' of pathline.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'uid', 'options', 'range', 'style_attribute',
         'accuracy_control', 'plot', 'step', 'skip', 'coarsen', 'onzone',
         'onphysics', 'field', 'surfaces_list', 'velocity_domain',
         'color_map', 'draw_mesh', 'mesh_object', 'display_state_name',
         'physics', 'geometry', 'surfaces', 'axes', 'curves']

    name: name_cls = name_cls
    """
    name child of pathline_child.
    """
    uid: uid_cls = uid_cls
    """
    uid child of pathline_child.
    """
    options: options_cls = options_cls
    """
    options child of pathline_child.
    """
    range: range_cls = range_cls
    """
    range child of pathline_child.
    """
    style_attribute: style_attribute_cls = style_attribute_cls
    """
    style_attribute child of pathline_child.
    """
    accuracy_control: accuracy_control_cls = accuracy_control_cls
    """
    accuracy_control child of pathline_child.
    """
    plot: plot_cls = plot_cls
    """
    plot child of pathline_child.
    """
    step: step_cls = step_cls
    """
    step child of pathline_child.
    """
    skip: skip_cls = skip_cls
    """
    skip child of pathline_child.
    """
    coarsen: coarsen_cls = coarsen_cls
    """
    coarsen child of pathline_child.
    """
    onzone: onzone_cls = onzone_cls
    """
    onzone child of pathline_child.
    """
    onphysics: onphysics_cls = onphysics_cls
    """
    onphysics child of pathline_child.
    """
    field: field_cls = field_cls
    """
    field child of pathline_child.
    """
    surfaces_list: surfaces_list_cls = surfaces_list_cls
    """
    surfaces_list child of pathline_child.
    """
    velocity_domain: velocity_domain_cls = velocity_domain_cls
    """
    velocity_domain child of pathline_child.
    """
    color_map: color_map_cls = color_map_cls
    """
    color_map child of pathline_child.
    """
    draw_mesh: draw_mesh_cls = draw_mesh_cls
    """
    draw_mesh child of pathline_child.
    """
    mesh_object: mesh_object_cls = mesh_object_cls
    """
    mesh_object child of pathline_child.
    """
    display_state_name: display_state_name_cls = display_state_name_cls
    """
    display_state_name child of pathline_child.
    """
    physics: physics_cls = physics_cls
    """
    physics child of pathline_child.
    """
    geometry: geometry_cls = geometry_cls
    """
    geometry child of pathline_child.
    """
    surfaces: surfaces_cls = surfaces_cls
    """
    surfaces child of pathline_child.
    """
    axes: axes_cls = axes_cls
    """
    axes child of pathline_child.
    """
    curves: curves_cls = curves_cls
    """
    curves child of pathline_child.
    """
    command_names = \
        ['display']

    display: display_cls = display_cls
    """
    display command of pathline_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option import option as option_cls
from .value_1 import value as value_cls
from .profile_name import profile_name as profile_name_cls
from .field_name import field_name as field_name_cls
from .udf import udf as udf_cls
class ocw_ship_vmag(Group):
    """
    'ocw_ship_vmag' child.
    """

    fluent_name = "ocw-ship-vmag"

    child_names = \
        ['option', 'value', 'profile_name', 'field_name', 'udf']

    option: option_cls = option_cls
    """
    option child of ocw_ship_vmag.
    """
    value: value_cls = value_cls
    """
    value child of ocw_ship_vmag.
    """
    profile_name: profile_name_cls = profile_name_cls
    """
    profile_name child of ocw_ship_vmag.
    """
    field_name: field_name_cls = field_name_cls
    """
    field_name child of ocw_ship_vmag.
    """
    udf: udf_cls = udf_cls
    """
    udf child of ocw_ship_vmag.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .style import style as style_cls
from .vector_length import vector_length as vector_length_cls
from .constant_color import constant_color as constant_color_cls
from .vector_of import vector_of as vector_of_cls
from .scale_1 import scale as scale_cls
from .length_to_head_ratio import length_to_head_ratio as length_to_head_ratio_cls
class vector_settings(Group):
    """
    'vector_settings' child.
    """

    fluent_name = "vector-settings"

    child_names = \
        ['style', 'vector_length', 'constant_color', 'vector_of', 'scale',
         'length_to_head_ratio']

    style: style_cls = style_cls
    """
    style child of vector_settings.
    """
    vector_length: vector_length_cls = vector_length_cls
    """
    vector_length child of vector_settings.
    """
    constant_color: constant_color_cls = constant_color_cls
    """
    constant_color child of vector_settings.
    """
    vector_of: vector_of_cls = vector_of_cls
    """
    vector_of child of vector_settings.
    """
    scale: scale_cls = scale_cls
    """
    scale child of vector_settings.
    """
    length_to_head_ratio: length_to_head_ratio_cls = length_to_head_ratio_cls
    """
    length_to_head_ratio child of vector_settings.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .list_properties import list_properties as list_properties_cls
from .cone_axis_vector_child import cone_axis_vector_child

class rotation_axis_origin(ListObject[cone_axis_vector_child]):
    """
    'rotation_axis_origin' child.
    """

    fluent_name = "rotation-axis-origin"

    command_names = \
        ['list_properties']

    list_properties: list_properties_cls = list_properties_cls
    """
    list_properties command of rotation_axis_origin.
    """
    child_object_type: cone_axis_vector_child = cone_axis_vector_child
    """
    child_object_type of rotation_axis_origin.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .law_1 import law_1 as law_1_cls
from .law_2 import law_2 as law_2_cls
from .law_3 import law_3 as law_3_cls
from .law_4 import law_4 as law_4_cls
from .law_5 import law_5 as law_5_cls
from .law_6 import law_6 as law_6_cls
from .law_7 import law_7 as law_7_cls
from .law_8 import law_8 as law_8_cls
from .law_9 import law_9 as law_9_cls
from .law_10 import law_10 as law_10_cls
from .switch import switch as switch_cls
class custom_laws(Group):
    """
    'custom_laws' child.
    """

    fluent_name = "custom-laws"

    child_names = \
        ['law_1', 'law_2', 'law_3', 'law_4', 'law_5', 'law_6', 'law_7',
         'law_8', 'law_9', 'law_10', 'switch']

    law_1: law_1_cls = law_1_cls
    """
    law_1 child of custom_laws.
    """
    law_2: law_2_cls = law_2_cls
    """
    law_2 child of custom_laws.
    """
    law_3: law_3_cls = law_3_cls
    """
    law_3 child of custom_laws.
    """
    law_4: law_4_cls = law_4_cls
    """
    law_4 child of custom_laws.
    """
    law_5: law_5_cls = law_5_cls
    """
    law_5 child of custom_laws.
    """
    law_6: law_6_cls = law_6_cls
    """
    law_6 child of custom_laws.
    """
    law_7: law_7_cls = law_7_cls
    """
    law_7 child of custom_laws.
    """
    law_8: law_8_cls = law_8_cls
    """
    law_8 child of custom_laws.
    """
    law_9: law_9_cls = law_9_cls
    """
    law_9 child of custom_laws.
    """
    law_10: law_10_cls = law_10_cls
    """
    law_10 child of custom_laws.
    """
    switch: switch_cls = switch_cls
    """
    switch child of custom_laws.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class dynamic_mechanism_reduction_min_target(Integer):
    """
    Specify minimum number of target species for dynamic mechanism reduction.
    """

    fluent_name = "dynamic-mechanism-reduction-min-target"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class all_len_modified(Boolean):
    """
    Modify all length scales in nut equation? (if no, destruction term only).
    """

    fluent_name = "all-len-modified?"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class use_window_resolution(Boolean):
    """
    Use the currently active window's resolution for hardcopy (ignores the x-resolution and y-resolution in this case).
    """

    fluent_name = "use-window-resolution?"




#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class report:
    fluent_name = ...
    child_names = ...
    simulation_reports = ...
    discrete_phase = ...
    fluxes = ...
    flow = ...
    modified_setting_options = ...
    population_balance = ...
    heat_exchanger = ...
    system = ...
    surface_integrals = ...
    volume_integrals = ...
    command_names = ...

    def aero_optical_distortions(self, ):
        """
        Optics report menu.
        """

    def forces(self, option: str, domain: str, all_wall_zones: bool, wall_zones: List[str], direction_vector: List[Union[float, str]], momentum_center: List[Union[float, str]], momentum_axis: List[Union[float, str]], pressure_coordinate: str, coordinate_value: Union[float, str], write_to_file: bool, file_name: str, append_data: bool):
        """
        'forces' command.
        
        Parameters
        ----------
            option : str
                'option' child.
            domain : str
                'domain' child.
            all_wall_zones : bool
                Select all wall zones available.
            wall_zones : typing.List[str]
                Enter wall zone name list.
            direction_vector : typing.List[real]
                'direction_vector' child.
            momentum_center : typing.List[real]
                'momentum_center' child.
            momentum_axis : typing.List[real]
                'momentum_axis' child.
            pressure_coordinate : str
                'pressure_coordinate' child.
            coordinate_value : real
                'coordinate_value' child.
            write_to_file : bool
                'write_to_file' child.
            file_name : str
                'file_name' child.
            append_data : bool
                'append_data' child.
        
        """

    def multiphase_summary(self, verbosity_option: str):
        """
        Multiphase Summary and Recommendations.
        
        Parameters
        ----------
            verbosity_option : str
                'verbosity_option' child.
        
        """

    def particle_summary(self, injection_names: List[str]):
        """
        Print summary report for all current particles.
        
        Parameters
        ----------
            injection_names : typing.List[str]
                'injection_names' child.
        
        """

    def pathline_summary(self, ):
        """
        Print path-line-summary report.
        """

    def projected_surface_area(self, surfaces: List[str], min_feature_size: Union[float, str], proj_plane_norm_comp: List[Union[float, str]]):
        """
        Print total area of the projection of a group of surfaces to a plane.
        
        Parameters
        ----------
            surfaces : typing.List[str]
                Select surface.
            min_feature_size : real
                'min_feature_size' child.
            proj_plane_norm_comp : typing.List[real]
                'proj_plane_norm_comp' child.
        
        """

    def summary(self, write_to_file: bool, file_name: str):
        """
        Print report summary.
        
        Parameters
        ----------
            write_to_file : bool
                'write_to_file' child.
            file_name : str
                'file_name' child.
        
        """

    def vbm(self, output_quantity: str, rotor_name: str, scale_output: bool, write_to_file: bool, file_name: str, append: bool):
        """
        'vbm' command.
        
        Parameters
        ----------
            output_quantity : str
                'output_quantity' child.
            rotor_name : str
                'rotor_name' child.
            scale_output : bool
                'scale_output' child.
            write_to_file : bool
                'write_to_file' child.
            file_name : str
                'file_name' child.
            append : bool
                'append' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .row_number import row_number as row_number_cls
from .column_number import column_number as column_number_cls
from .row_value import row_value as row_value_cls
from .column_value import column_value as column_value_cls
from .table_value import table_value as table_value_cls
class table_voc_c(Group):
    """
    'table_voc_c' child.
    """

    fluent_name = "table-voc-c"

    child_names = \
        ['row_number', 'column_number', 'row_value', 'column_value',
         'table_value']

    row_number: row_number_cls = row_number_cls
    """
    row_number child of table_voc_c.
    """
    column_number: column_number_cls = column_number_cls
    """
    column_number child of table_voc_c.
    """
    row_value: row_value_cls = row_value_cls
    """
    row_value child of table_voc_c.
    """
    column_value: column_value_cls = column_value_cls
    """
    column_value child of table_voc_c.
    """
    table_value: table_value_cls = table_value_cls
    """
    table_value child of table_voc_c.
    """



from ctypes import c_int, sizeof
from dataclasses import dataclass
import itertools
import logging
import os
from pathlib import Path
import socket
import subprocess
import threading
from typing import Any, Callable, Dict, List, Optional, Tuple, Union
import warnings
import weakref

from docker.models.containers import Container
import grpc
import psutil

from ansys.fluent.core.services import service_creator
from ansys.fluent.core.services.health_check import HealthCheckService
from ansys.fluent.core.services.scheme_eval import SchemeEvalService
from ansys.fluent.core.utils.execution import timeout_exec, timeout_loop
from ansys.platform.instancemanagement import Instance
import docker

logger = logging.getLogger("pyfluent.general")


class PortNotProvided(ValueError):
    """Provides the error when port is not provided."""

    def __init__(self):
        super().__init__(
            "Provide the 'port' to connect to an existing Fluent instance."
        )


class UnsupportedRemoteFluentInstance(ValueError):
    """Provides the error when 'wait_process_finished' does not support remote Fluent
    session."""

    def __init__(self):
        super().__init__("Remote Fluent instance is unsupported.")


class WaitTypeError(TypeError):
    """Provides the error when invalid ``wait`` type is provided."""

    def __init__(self):
        super().__init__("Invalid 'wait' type.")


def _get_max_c_int_limit() -> int:
    """Get the maximum limit of a C int.

    Returns
    -------
    int
        The maximum limit of a C int
    """
    return 2 ** (sizeof(c_int) * 8 - 1) - 1


class MonitorThread(threading.Thread):
    """A class used for monitoring a Fluent session.

    Daemon thread which will ensure cleanup of session objects, shutdown of
    non-deamon threads etc.

    Attributes
    ----------
    cbs : List[Callable]
        Cleanup/shutdown functions
    """

    def __init__(self):
        super().__init__(daemon=True)
        self.cbs: List[Callable] = []

    def run(self) -> None:
        """Run monitor thread."""
        main_thread = threading.main_thread()
        main_thread.join()
        for cb in self.cbs:
            cb()


def get_container(container_id_or_name: str) -> Union[bool, Container, None]:
    """Get the Docker container object.

    Returns
    -------
    Union[bool, Container, None]
        If the system is not correctly set up to run Docker containers, returns ``None``.
        If the container was not found, returns ``False``.
        If the container is found, returns the associated Docker container object.

    Notes
    -----
    See `Docker container`_ for more information.

    .. _Docker container: https://docker-py.readthedocs.io/en/stable/containers.html#docker.models.containers.Container
    """
    if not isinstance(container_id_or_name, str):
        container_id_or_name = str(container_id_or_name)
    try:
        docker_client = docker.from_env()
        container = docker_client.containers.get(container_id_or_name)
    except docker.errors.NotFound:  # NotFound is a child from DockerException
        return False
    except docker.errors.DockerException as exc:
        logger.info(f"{type(exc).__name__}: {exc}")
        return None
    return container


class ErrorState:
    """Object to indicate the error state of the connected Fluent client.

    Examples
    --------
    >>> import ansys.fluent.core as pyfluent
    >>> session = pyfluent.launch_fluent()
    >>> session.fluent_connection.error_state.set("test", "test details")
    >>> session.fluent_connection.error_state.name
    'test'
    >>> session.fluent_connection.error_state.details
    'test details'
    >>> session.fluent_connection.error_state.clear()
    >>> session.fluent_connection.error_state.name
    ''
    """

    @property
    def name(self):
        return self._name

    @property
    def details(self):
        return self._details

    def __init__(self, name: str = "", details: str = ""):
        """Initializes the error state object.

        Parameters
        ----------
            name : str
                The name of the error state, by default an empty string, indicating no errors.
            details : str
                Additional details of the error, by default an empty string.
        """
        self._name = name
        self._details = details

    def set(self, name: str, details: str):
        """Method to set the error state name and details to new values."""
        self._name = name
        self._details = details

    def clear(self):
        """Method to clear the current error state, emptying the error name and details
        properties."""
        self._name = ""
        self._details = ""


@dataclass(frozen=True)
class FluentConnectionProperties:
    """Stores Fluent connection properties, including connection IP, port and password;
    Fluent Cortex working directory, process ID and hostname; and whether Fluent was
    launched in a docker container.

    Examples
    --------
    These properties are also available through the session object and can be accessed as:

    >>> import ansys.fluent.core as pyfluent
    >>> session = pyfluent.launch_fluent()
    >>> session.connection_properties.list_names()
    ['ip', 'port', 'password', 'cortex_pwd', 'cortex_pid', 'cortex_host', 'inside_container']
    >>> session.connection_properties.ip
    '127.0.0.1'
    """

    ip: Optional[str] = None
    port: Optional[int] = None
    password: Optional[str] = None
    cortex_pwd: Optional[str] = None
    cortex_pid: Optional[int] = None
    cortex_host: Optional[str] = None
    fluent_host_pid: Optional[int] = None
    inside_container: Optional[Union[bool, Container, None]] = None

    def list_names(self) -> list:
        """Returns list with all property names."""
        return [k for k, _ in vars(self).items()]

    def list_values(self) -> dict:
        """Returns dictionary with all property names and values."""
        return vars(self)


class FluentConnection:
    """Encapsulates a Fluent connection.

    Methods
    -------
    check_health()
        Check health of Fluent connection.
    exit()
        Close the Fluent connection and exit Fluent.
    """

    _on_exit_cbs: List[Callable] = []
    _id_iter = itertools.count()
    _monitor_thread: Optional[MonitorThread] = None
    _writing_transcript_to_interpreter = False

    def __init__(
        self,
        ip: Optional[str] = None,
        port: Optional[int] = None,
        password: Optional[str] = None,
        channel: Optional[grpc.Channel] = None,
        cleanup_on_exit: bool = True,
        start_transcript: bool = True,
        remote_instance: Optional[Instance] = None,
        launcher_args: Optional[Dict[str, Any]] = None,
        inside_container: Optional[bool] = None,
    ):
        """Initialize a Session.

        Parameters
        ----------
        ip : str, optional
            IP address to connect to existing Fluent instance. Used only
            when ``channel`` is ``None``.  Defaults to ``"127.0.0.1"``
            and can also be set by the environment variable
            ``PYFLUENT_FLUENT_IP=<ip>``.
        port : int, optional
            Port to connect to existing Fluent instance. Used only
            when ``channel`` is ``None``.  Defaults value can be set by
            the environment variable ``PYFLUENT_FLUENT_PORT=<port>``.
        password : str, optional
            Password to connect to existing Fluent instance.
        channel : grpc.Channel, optional
            Grpc channel to use to connect to existing Fluent instance.
            ip and port arguments will be ignored when channel is
            specified.
        cleanup_on_exit : bool, optional
            When True, the connected Fluent session will be shut down
            when PyFluent is exited or exit() is called on the session
            instance, by default True.
        start_transcript : bool, optional
            The Fluent transcript is started in the client only when
            start_transcript is True. It can be started and stopped
            subsequently via method calls on the Session object.
        remote_instance : ansys.platform.instancemanagement.Instance
            The corresponding remote instance when Fluent is launched through
            PyPIM. This instance will be deleted when calling
            ``Session.exit()``.
        inside_container: bool, optional
            Whether the Fluent session that is being connected to
            is running inside a docker container.

        Raises
        ------
        PortNotProvided
            If port is not provided.
        """
        self.error_state = ErrorState()
        self._data_valid = False
        self._channel_str = None
        self._slurm_job_id = None
        self.finalizer_cbs = []
        if channel is not None:
            self._channel = channel
        else:
            if not ip:
                ip = os.getenv("PYFLUENT_FLUENT_IP", "127.0.0.1")
            if not port:
                port = os.getenv("PYFLUENT_FLUENT_PORT")
            self._channel_str = f"{ip}:{port}"
            if not port:
                raise PortNotProvided()
            # Same maximum message length is used in the server
            max_message_length = _get_max_c_int_limit()
            self._channel = grpc.insecure_channel(
                f"{ip}:{port}",
                options=[
                    ("grpc.max_send_message_length", max_message_length),
                    ("grpc.max_receive_message_length", max_message_length),
                ],
            )
        self._metadata: List[Tuple[str, str]] = (
            [("password", password)] if password else []
        )

        self.health_check_service = HealthCheckService(
            self._channel, self._metadata, self.error_state
        )
        # At this point, the server must be running. If the following check_health()
        # throws, we should not proceed.
        self.health_check_service.check_health()

        self._slurm_job_id = launcher_args and launcher_args.get("slurm_job_id")

        self._id = f"session-{next(FluentConnection._id_iter)}"

        if not FluentConnection._monitor_thread:
            FluentConnection._monitor_thread = MonitorThread()
            FluentConnection._monitor_thread.start()

        # Move this service later.
        # Currently, required by launcher to connect to a running session.
        self._scheme_eval_service = self.create_grpc_service(
            SchemeEvalService, self.error_state
        )
        self.scheme_eval = service_creator("scheme_eval").create(
            self._scheme_eval_service
        )

        self._cleanup_on_exit = cleanup_on_exit
        self.start_transcript = start_transcript
        from grpc._channel import _InactiveRpcError

        try:
            logger.debug("Obtaining Cortex connection properties...")
            fluent_host_pid = self.scheme_eval.scheme_eval("(cx-client-id)")
            cortex_host = self.scheme_eval.scheme_eval("(cx-cortex-host)")
            cortex_pid = self.scheme_eval.scheme_eval("(cx-cortex-id)")
            cortex_pwd = self.scheme_eval.scheme_eval("(cortex-pwd)")
            logger.debug("Cortex connection properties successfully obtained.")
        except _InactiveRpcError:
            logger.warning(
                "Fluent Cortex properties unobtainable, force exit and other"
                "methods are not going to work properly, proceeding..."
            )
            cortex_host = None
            cortex_pid = None
            cortex_pwd = None
            fluent_host_pid = None

        if (
            (inside_container is None or inside_container is True)
            and not remote_instance
            and cortex_host is not None
        ):
            logger.info("Checking if Fluent is running inside a container.")
            inside_container = get_container(cortex_host)
            logger.debug(f"get_container({cortex_host}): {inside_container}")
            if inside_container is False:
                logger.info("Fluent is not running inside a container.")
            elif inside_container is None:
                logger.info(
                    "The current system does not support Docker containers. "
                    "Assuming Fluent is not inside a container."
                )

        self.connection_properties = FluentConnectionProperties(
            ip,
            port,
            password,
            cortex_pwd,
            cortex_pid,
            cortex_host,
            fluent_host_pid,
            inside_container,
        )

        self._remote_instance = remote_instance
        self.launcher_args = launcher_args

        self._exit_event = threading.Event()

        # session.exit() is handled in the daemon thread (MonitorThread) which ensures
        # shutdown of non-daemon threads. A daemon thread is terminated abruptly
        # during interpreter exit, after all non-daemon threads are exited.
        # self._waiting_thread is a long-running thread which is exited
        # at the end of session.exit() to ensure everything within session.exit()
        # gets executed during exit.
        self._waiting_thread = threading.Thread(target=self._exit_event.wait)
        self._waiting_thread.start()

        self._finalizer = weakref.finalize(
            self,
            FluentConnection._exit,
            self._channel,
            self._cleanup_on_exit,
            self.scheme_eval,
            self.finalizer_cbs,
            self._remote_instance,
            self._exit_event,
        )
        FluentConnection._monitor_thread.cbs.append(self._finalizer)

    def _close_slurm(self):
        subprocess.run(["scancel", f"{self._slurm_job_id}"])

    def force_exit(self):
        """Immediately terminates the Fluent client, losing unsaved progress and data.

        Notes
        -----
        If the Fluent session is responsive, prefer using :func:`exit()` instead.

        Examples
        --------
        >>> import ansys.fluent.core as pyfluent
        >>> session = pyfluent.launch_fluent()
        >>> session.force_exit()
        """
        if self.connection_properties.inside_container:
            logger.error(
                "Cannot execute cleanup script, Fluent running inside container. "
                "Use force_exit_container() instead."
            )
            return
        if self._remote_instance is not None:
            logger.error("Cannot execute cleanup script, Fluent running remotely.")
            return

        pwd = self.connection_properties.cortex_pwd
        pid = self.connection_properties.fluent_host_pid
        host = self.connection_properties.cortex_host
        if host != socket.gethostname():
            logger.error(
                "Fluent host is not the current host, cancelling forced exit..."
            )
            return
        if os.name == "nt":
            cleanup_file_ext = "bat"
            cmd_list = []
        elif os.name == "posix":
            cleanup_file_ext = "sh"
            cmd_list = ["bash"]
        else:
            logger.error(
                "Unrecognized or unsupported operating system, cancelling Fluent cleanup script execution."
            )
            return
        cleanup_file_name = f"cleanup-fluent-{host}-{pid}.{cleanup_file_ext}"
        logger.debug(f"Looking for {cleanup_file_name}...")
        cleanup_file_name = Path(pwd, cleanup_file_name)
        if cleanup_file_name.is_file():
            logger.info(
                f"Executing Fluent cleanup script, file path: {cleanup_file_name}"
            )
            cmd_list.append(cleanup_file_name)
            logger.debug(f"Cleanup command list = {cmd_list}")
            subprocess.Popen(
                cmd_list,
                stdout=subprocess.DEVNULL,
                stderr=subprocess.DEVNULL,
            )
        elif self._slurm_job_id:
            logger.debug("Fluent running inside Slurm, closing Slurm session...")
            self._close_slurm()
        else:
            logger.error("Could not find cleanup file.")

    def force_exit_container(self):
        """Immediately terminates the Fluent client running inside a container, losing
        unsaved progress and data.

        Notes
        -----
        By default, Fluent does not run in a container,
        in that case use :func:`force_exit()`.
        If the Fluent session is responsive, prefer using :func:`exit()` instead.
        """
        if self._remote_instance is not None:
            logger.error(
                "Fluent is running remotely, cannot terminate Fluent container."
            )
            return
        container = self.connection_properties.inside_container
        if not container:
            logger.error(
                "Session is not inside a container, cannot terminate Fluent container. "
                "Try force_exit() instead."
            )
            return
        container_id = self.connection_properties.cortex_host
        pid = self.connection_properties.fluent_host_pid
        cleanup_file_name = f"cleanup-fluent-{container_id}-{pid}.sh"
        logger.debug(f"Executing Fluent container cleanup script: {cleanup_file_name}")
        if get_container(container_id):
            try:
                container.exec_run(["bash", cleanup_file_name], detach=True)
            except docker.errors.APIError as e:
                logger.info(f"{type(e).__name__}: {e}")
                logger.debug(
                    "Caught Docker APIError, Docker container probably not running anymore."
                )
        else:
            logger.debug("Container not found, cancelling cleanup script execution.")

    def register_finalizer_cb(self, cb):
        """Register a callback to run with the finalizer."""
        self.finalizer_cbs.append(cb)

    def create_grpc_service(self, service, *args):
        """Create a gRPC service.

        Parameters
        ----------
        service : Any
            service class
        args : Any, optional
            additional arguments, by default empty

        Returns
        -------
        Any
            service object
        """
        return service(self._channel, self._metadata, *args)

    def check_health(self) -> str:
        """Check health of Fluent connection."""
        warnings.warn("Use -> health_check_service.status()", DeprecationWarning)
        return self.health_check_service.status()

    def wait_process_finished(self, wait: Union[float, int, bool] = 60):
        """Returns ``True`` if local Fluent processes have finished, ``False`` if they
        are still running when wait limit (default 60 seconds) is reached. Immediately
        cancels and returns ``None`` if ``wait`` is set to ``False``.

        Parameters
        ----------
        wait : float, int or bool, optional
            How long to wait for processes to finish before returning, by default 60 seconds.
            Can also be set to ``True``, which will result in waiting indefinitely.

        Raises
        ------
        UnsupportedRemoteFluentInstance
            If current Fluent instance is running remotely.
        WaitTypeError
            If ``wait`` is specified improperly.
        """
        if self._remote_instance:
            raise UnsupportedRemoteFluentInstance()
        if isinstance(wait, bool):
            if wait:
                wait = 60
            else:
                logger.debug("Wait limit set to 'False', cancelling process wait.")
                return
        if isinstance(wait, (float, int)):
            logger.info(f"Waiting {wait} seconds for Fluent processes to finish...")
        else:
            raise WaitTypeError()
        if self.connection_properties.inside_container:
            _response = timeout_loop(
                get_container,
                wait,
                args=(self.connection_properties.cortex_host,),
                idle_period=0.5,
                expected="falsy",
            )
        else:
            _response = timeout_loop(
                lambda connection: psutil.pid_exists(connection.fluent_host_pid)
                or psutil.pid_exists(connection.cortex_pid),
                wait,
                args=(self.connection_properties,),
                idle_period=0.5,
                expected="falsy",
            )
        return not _response

    def exit(
        self,
        timeout: Optional[float] = None,
        timeout_force: bool = True,
        wait: Optional[Union[float, int, bool]] = False,
    ) -> None:
        """Close the Fluent connection and exit Fluent.

        Parameters
        ----------
        timeout : float, optional
            Time in seconds before considering that the exit request has timed out.
            If omitted or specified as None, then the request will not time out and will lock up the interpreter
            while waiting for a response. Will return earlier if request succeeds earlier.
        timeout_force : bool, optional
            If not specified, defaults to ``True``. If ``True``, attempts to terminate the Fluent process if
            exit request reached timeout. If no timeout is set, this option is ignored.
            Executes :func:`force_exit()` or :func:`force_exit_container()`,
            depending on how Fluent was launched.
        wait : float, int or bool, optional
            Specifies whether to wait for local Fluent processes to finish completely before proceeding.
            If omitted or specified as ``False``, will proceed as usual without
            waiting for the Fluent processes to finish.
            Can be set to ``True`` which will wait for up to 60 seconds,
            or set to a float or int value to specify the wait limit.
            If wait limit is reached, will forcefully terminate the Fluent process.
            If set to wait, will return as soon as processes completely finish.
            Does not work for remote Fluent processes.

        Notes
        -----
        Can also set the ``PYFLUENT_TIMEOUT_FORCE_EXIT`` environment variable to specify the number of seconds and
        alter the default ``timeout`` value. Setting this env var to a non-number value, such as ``OFF``,
        will return this function to default behavior. Note that the environment variable will be ignored if
        timeout is specified when calling this function.

        Examples
        --------

        >>> import ansys.fluent.core as pyfluent
        >>> session = pyfluent.launch_fluent()
        >>> session.exit()
        """

        if wait is not False and self._remote_instance:
            logger.warning(
                "Session exit 'wait' option is ignored when working with remote Fluent sessions."
            )

        if timeout is None:
            env_timeout = os.getenv("PYFLUENT_TIMEOUT_FORCE_EXIT")

            if env_timeout:
                logger.debug("Found PYFLUENT_TIMEOUT_FORCE_EXIT env var")
                try:
                    timeout = float(env_timeout)
                    logger.debug(f"Setting TIMEOUT_FORCE_EXIT to {timeout}")
                except ValueError:
                    logger.debug(
                        "Off or unrecognized PYFLUENT_TIMEOUT_FORCE_EXIT value, not enabling timeout force exit"
                    )

        if timeout is None:
            logger.info("Finalizing Fluent connection...")
            self._finalizer()
            if wait is not False:
                self.wait_process_finished(wait=wait)
        else:
            if not self.health_check_service.is_serving:
                logger.debug("gRPC service not working, cancelling soft exit call.")
            else:
                logger.info("Attempting to send exit request to Fluent...")
                success = timeout_exec(self._finalizer, timeout)
                if success:
                    if wait is not False:
                        if self.wait_process_finished(wait=wait):
                            return
                    else:
                        return

            logger.debug("Continuing...")
            if (timeout is not None and timeout_force) or isinstance(
                wait, (float, int)
            ):
                if self._remote_instance:
                    logger.warning("Cannot force exit from Fluent remote instance.")
                    return
                elif self.connection_properties.inside_container:
                    logger.debug(
                        "Fluent running inside container, cleaning up Fluent inside container..."
                    )
                    self.force_exit_container()
                else:
                    logger.debug(
                        "Fluent running locally, cleaning up Fluent processes..."
                    )
                    self.force_exit()
                logger.debug("Done.")
            else:
                logger.debug("Timeout and wait force exit disabled, returning...")

    @staticmethod
    def _exit(
        channel,
        cleanup_on_exit,
        scheme_eval,
        finalizer_cbs,
        remote_instance,
        exit_event,
    ) -> None:
        logger.debug("FluentConnection exit method called.")
        if channel:
            for cb in finalizer_cbs:
                cb()
            if cleanup_on_exit:
                try:
                    scheme_eval.exec(("(exit-server)",))
                except Exception:
                    pass
            channel.close()
            channel = None

        if remote_instance:
            remote_instance.delete()

        exit_event.set()



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .use_multi_physics import use_multi_physics as use_multi_physics_cls
from .threshold import threshold as threshold_cls
from .interval import interval as interval_cls
class physical_models(Group):
    """
    Use physical-models load balancing?.
    """

    fluent_name = "physical-models"

    child_names = \
        ['use_multi_physics', 'threshold', 'interval']

    use_multi_physics: use_multi_physics_cls = use_multi_physics_cls
    """
    use_multi_physics child of physical_models.
    """
    threshold: threshold_cls = threshold_cls
    """
    threshold child of physical_models.
    """
    interval: interval_cls = interval_cls
    """
    interval child of physical_models.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .keep_linearized_source_terms_constant import keep_linearized_source_terms_constant as keep_linearized_source_terms_constant_cls
from .source_term_linearization_enabled import source_term_linearization_enabled as source_term_linearization_enabled_cls
from .enhanced_linearization_enabled import enhanced_linearization_enabled as enhanced_linearization_enabled_cls
from .linearized_source_terms_limiter import linearized_source_terms_limiter as linearized_source_terms_limiter_cls
class linearization(Group):
    """
    Menu containing options to enable/disable linearization of DPM source terms. 
    Please note that source term linearization is only available if the node-based averaging option is not active.
    """

    fluent_name = "linearization"

    child_names = \
        ['keep_linearized_source_terms_constant',
         'source_term_linearization_enabled',
         'enhanced_linearization_enabled', 'linearized_source_terms_limiter']

    keep_linearized_source_terms_constant: keep_linearized_source_terms_constant_cls = keep_linearized_source_terms_constant_cls
    """
    keep_linearized_source_terms_constant child of linearization.
    """
    source_term_linearization_enabled: source_term_linearization_enabled_cls = source_term_linearization_enabled_cls
    """
    source_term_linearization_enabled child of linearization.
    """
    enhanced_linearization_enabled: enhanced_linearization_enabled_cls = enhanced_linearization_enabled_cls
    """
    enhanced_linearization_enabled child of linearization.
    """
    linearized_source_terms_limiter: linearized_source_terms_limiter_cls = linearized_source_terms_limiter_cls
    """
    linearized_source_terms_limiter child of linearization.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option_2 import option as option_cls
from .smooth import smooth as smooth_cls
from .banded import banded as banded_cls
class coloring(Group):
    """
    'coloring' child.
    """

    fluent_name = "coloring"

    child_names = \
        ['option', 'smooth', 'banded']

    option: option_cls = option_cls
    """
    option child of coloring.
    """
    smooth: smooth_cls = smooth_cls
    """
    smooth child of coloring.
    """
    banded: banded_cls = banded_cls
    """
    banded child of coloring.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .set_1 import set as set_cls
from .list_properties_2 import list_properties as list_properties_cls
class poor_mesh_numerics(Group):
    """
    'poor_mesh_numerics' child.
    """

    fluent_name = "poor-mesh-numerics"

    child_names = \
        ['set']

    set: set_cls = set_cls
    """
    set child of poor_mesh_numerics.
    """
    command_names = \
        ['list_properties']

    list_properties: list_properties_cls = list_properties_cls
    """
    list_properties command of poor_mesh_numerics.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class relative_convergence_criterion(Real):
    """
    Specify convergence tolerance for the timestep iterations
    as the target residual reduction factor.
    """

    fluent_name = "relative-convergence-criterion"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option_2 import option as option_cls
from .direction_vector_2 import direction_vector as direction_vector_cls
from .curve_length import curve_length as curve_length_cls
class plot_direction(Group):
    """
    'plot_direction' child.
    """

    fluent_name = "plot-direction"

    child_names = \
        ['option', 'direction_vector', 'curve_length']

    option: option_cls = option_cls
    """
    option child of plot_direction.
    """
    direction_vector: direction_vector_cls = direction_vector_cls
    """
    direction_vector child of plot_direction.
    """
    curve_length: curve_length_cls = curve_length_cls
    """
    curve_length child of plot_direction.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .outer_iterations import outer_iterations as outer_iterations_cls
from .initial_outer_iterations import initial_outer_iterations as initial_outer_iterations_cls
from .instability_detector import instability_detector as instability_detector_cls
class hybrid_nita(Group):
    """
    Hybrid NITA stability controls for multiphase flow.
    """

    fluent_name = "hybrid-nita"

    child_names = \
        ['outer_iterations', 'initial_outer_iterations',
         'instability_detector']

    outer_iterations: outer_iterations_cls = outer_iterations_cls
    """
    outer_iterations child of hybrid_nita.
    """
    initial_outer_iterations: initial_outer_iterations_cls = initial_outer_iterations_cls
    """
    initial_outer_iterations child of hybrid_nita.
    """
    instability_detector: instability_detector_cls = instability_detector_cls
    """
    instability_detector child of hybrid_nita.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class vof_min_seeding(Real):
    """
    Minimum vof seeding for non-zero area density in heat and mass transfer.
    """

    fluent_name = "vof-min-seeding"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class last_species(String, _HasAllowedValuesMixin):
    """
    The last species should be the most abundant one, no transport equation will be solved for it.
    """

    fluent_name = "last-species"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option_10 import option as option_cls
from .value_1 import value as value_cls
from .expression import expression as expression_cls
from .polynomial import polynomial as polynomial_cls
from .user_defined_function import user_defined_function as user_defined_function_cls
from .anisotropic import anisotropic as anisotropic_cls
from .orthotropic import orthotropic as orthotropic_cls
from .cyl_orthotropic import cyl_orthotropic as cyl_orthotropic_cls
class uds_diffusivities_child(Group):
    """
    'child_object_type' of uds_diffusivities.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['option', 'value', 'expression', 'polynomial',
         'user_defined_function', 'anisotropic', 'orthotropic',
         'cyl_orthotropic']

    option: option_cls = option_cls
    """
    option child of uds_diffusivities_child.
    """
    value: value_cls = value_cls
    """
    value child of uds_diffusivities_child.
    """
    expression: expression_cls = expression_cls
    """
    expression child of uds_diffusivities_child.
    """
    polynomial: polynomial_cls = polynomial_cls
    """
    polynomial child of uds_diffusivities_child.
    """
    user_defined_function: user_defined_function_cls = user_defined_function_cls
    """
    user_defined_function child of uds_diffusivities_child.
    """
    anisotropic: anisotropic_cls = anisotropic_cls
    """
    anisotropic child of uds_diffusivities_child.
    """
    orthotropic: orthotropic_cls = orthotropic_cls
    """
    orthotropic child of uds_diffusivities_child.
    """
    cyl_orthotropic: cyl_orthotropic_cls = cyl_orthotropic_cls
    """
    cyl_orthotropic child of uds_diffusivities_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .type_of_smoothing import type_of_smoothing as type_of_smoothing_cls
from .number_of_iterations import number_of_iterations as number_of_iterations_cls
from .relaxtion_factor import relaxtion_factor as relaxtion_factor_cls
from .percentage_of_cells import percentage_of_cells as percentage_of_cells_cls
from .skewness_threshold import skewness_threshold as skewness_threshold_cls
class smooth_mesh(Command):
    """
    Smooth the mesh using quality-based, Laplace or skewness methods.
    
    Parameters
    ----------
        type_of_smoothing : str
            'type_of_smoothing' child.
        number_of_iterations : int
            'number_of_iterations' child.
        relaxtion_factor : real
            'relaxtion_factor' child.
        percentage_of_cells : real
            'percentage_of_cells' child.
        skewness_threshold : real
            'skewness_threshold' child.
    
    """

    fluent_name = "smooth-mesh"

    argument_names = \
        ['type_of_smoothing', 'number_of_iterations', 'relaxtion_factor',
         'percentage_of_cells', 'skewness_threshold']

    type_of_smoothing: type_of_smoothing_cls = type_of_smoothing_cls
    """
    type_of_smoothing argument of smooth_mesh.
    """
    number_of_iterations: number_of_iterations_cls = number_of_iterations_cls
    """
    number_of_iterations argument of smooth_mesh.
    """
    relaxtion_factor: relaxtion_factor_cls = relaxtion_factor_cls
    """
    relaxtion_factor argument of smooth_mesh.
    """
    percentage_of_cells: percentage_of_cells_cls = percentage_of_cells_cls
    """
    percentage_of_cells argument of smooth_mesh.
    """
    skewness_threshold: skewness_threshold_cls = skewness_threshold_cls
    """
    skewness_threshold argument of smooth_mesh.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class volume_integrals:
    fluent_name = ...
    command_names = ...

    def mass_average(self, cell_zones: List[str], cell_function: str, current_domain: str, write_to_file: bool, file_name: str, append_data: bool):
        """
        Print mass-average of scalar over specified cell zones.
        
        Parameters
        ----------
            cell_zones : typing.List[str]
                Volume id/name.
            cell_function : str
                Specify Field.
            current_domain : str
                'current_domain' child.
            write_to_file : bool
                'write_to_file' child.
            file_name : str
                'file_name' child.
            append_data : bool
                'append_data' child.
        
        """

    def mass_integral(self, cell_zones: List[str], cell_function: str, current_domain: str, write_to_file: bool, file_name: str, append_data: bool):
        """
        Print mass-weighted integral of scalar over specified cell zones.
        
        Parameters
        ----------
            cell_zones : typing.List[str]
                Volume id/name.
            cell_function : str
                Specify Field.
            current_domain : str
                'current_domain' child.
            write_to_file : bool
                'write_to_file' child.
            file_name : str
                'file_name' child.
            append_data : bool
                'append_data' child.
        
        """

    def mass(self, cell_zones: List[str], cell_function: str, current_domain: str, write_to_file: bool, file_name: str, append_data: bool):
        """
        Print total mass of specified cell zones.
        
        Parameters
        ----------
            cell_zones : typing.List[str]
                Volume id/name.
            cell_function : str
                Specify Field.
            current_domain : str
                'current_domain' child.
            write_to_file : bool
                'write_to_file' child.
            file_name : str
                'file_name' child.
            append_data : bool
                'append_data' child.
        
        """

    def sum(self, cell_zones: List[str], cell_function: str, current_domain: str, write_to_file: bool, file_name: str, append_data: bool):
        """
        Print sum of scalar over specified cell zones.
        
        Parameters
        ----------
            cell_zones : typing.List[str]
                Volume id/name.
            cell_function : str
                Specify Field.
            current_domain : str
                'current_domain' child.
            write_to_file : bool
                'write_to_file' child.
            file_name : str
                'file_name' child.
            append_data : bool
                'append_data' child.
        
        """

    def twopisum(self, cell_zones: List[str], cell_function: str, current_domain: str, write_to_file: bool, file_name: str, append_data: bool):
        """
        Print sum of scalar over specified cell zones multiplied by 2*Pi.
        
        Parameters
        ----------
            cell_zones : typing.List[str]
                Volume id/name.
            cell_function : str
                Specify Field.
            current_domain : str
                'current_domain' child.
            write_to_file : bool
                'write_to_file' child.
            file_name : str
                'file_name' child.
            append_data : bool
                'append_data' child.
        
        """

    def minimum(self, cell_zones: List[str], cell_function: str, current_domain: str, write_to_file: bool, file_name: str, append_data: bool):
        """
        Print minimum of scalar over specified cell zones.
        
        Parameters
        ----------
            cell_zones : typing.List[str]
                Volume id/name.
            cell_function : str
                Specify Field.
            current_domain : str
                'current_domain' child.
            write_to_file : bool
                'write_to_file' child.
            file_name : str
                'file_name' child.
            append_data : bool
                'append_data' child.
        
        """

    def maximum(self, cell_zones: List[str], cell_function: str, current_domain: str, write_to_file: bool, file_name: str, append_data: bool):
        """
        Print maximum of scalar over specified cell zones.
        
        Parameters
        ----------
            cell_zones : typing.List[str]
                Volume id/name.
            cell_function : str
                Specify Field.
            current_domain : str
                'current_domain' child.
            write_to_file : bool
                'write_to_file' child.
            file_name : str
                'file_name' child.
            append_data : bool
                'append_data' child.
        
        """

    def volume(self, cell_zones: List[str], cell_function: str, current_domain: str, write_to_file: bool, file_name: str, append_data: bool):
        """
        Print total volume of specified cell zones.
        
        Parameters
        ----------
            cell_zones : typing.List[str]
                Volume id/name.
            cell_function : str
                Specify Field.
            current_domain : str
                'current_domain' child.
            write_to_file : bool
                'write_to_file' child.
            file_name : str
                'file_name' child.
            append_data : bool
                'append_data' child.
        
        """

    def volume_average(self, cell_zones: List[str], cell_function: str, current_domain: str, write_to_file: bool, file_name: str, append_data: bool):
        """
        Print volume-weighted average of scalar over specified cell zones.
        
        Parameters
        ----------
            cell_zones : typing.List[str]
                Volume id/name.
            cell_function : str
                Specify Field.
            current_domain : str
                'current_domain' child.
            write_to_file : bool
                'write_to_file' child.
            file_name : str
                'file_name' child.
            append_data : bool
                'append_data' child.
        
        """

    def volume_integral(self, cell_zones: List[str], cell_function: str, current_domain: str, write_to_file: bool, file_name: str, append_data: bool):
        """
        Print volume integral of scalar over specified cell zones.
        
        Parameters
        ----------
            cell_zones : typing.List[str]
                Volume id/name.
            cell_function : str
                Specify Field.
            current_domain : str
                'current_domain' child.
            write_to_file : bool
                'write_to_file' child.
            file_name : str
                'file_name' child.
            append_data : bool
                'append_data' child.
        
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .parts import parts as parts_cls
from .list_topology import list_topology as list_topology_cls
class geometry(Group):
    """
    'geometry' child.
    """

    fluent_name = "geometry"

    child_names = \
        ['parts']

    parts: parts_cls = parts_cls
    """
    parts child of geometry.
    """
    command_names = \
        ['list_topology']

    list_topology: list_topology_cls = list_topology_cls
    """
    list_topology command of geometry.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .wave_list_shallow_child import wave_list_shallow_child

class wave_list_shallow(ListObject[wave_list_shallow_child]):
    """
    'wave_list_shallow' child.
    """

    fluent_name = "wave-list-shallow"

    child_object_type: wave_list_shallow_child = wave_list_shallow_child
    """
    child_object_type of wave_list_shallow.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class rich_equivalence_ratio_limit(Real):
    """
    Specify the Rich equivalence ratio limit.
    """

    fluent_name = "rich-equivalence-ratio-limit"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .injections_1 import injections as injections_cls
from .boundaries_1 import boundaries as boundaries_cls
from .lines_1 import lines as lines_cls
from .planes import planes as planes_cls
from .op_udf import op_udf as op_udf_cls
from .append_sample import append_sample as append_sample_cls
from .accumulate_rates import accumulate_rates as accumulate_rates_cls
class start_file_write(Command):
    """
    'start_file_write' command.
    
    Parameters
    ----------
        injections : typing.List[str]
            'injections' child.
        boundaries : typing.List[str]
            'boundaries' child.
        lines : typing.List[str]
            Select surface.
        planes : typing.List[str]
            Select surface.
        op_udf : str
            'op_udf' child.
        append_sample : bool
            'append_sample' child.
        accumulate_rates : bool
            'accumulate_rates' child.
    
    """

    fluent_name = "start-file-write"

    argument_names = \
        ['injections', 'boundaries', 'lines', 'planes', 'op_udf',
         'append_sample', 'accumulate_rates']

    injections: injections_cls = injections_cls
    """
    injections argument of start_file_write.
    """
    boundaries: boundaries_cls = boundaries_cls
    """
    boundaries argument of start_file_write.
    """
    lines: lines_cls = lines_cls
    """
    lines argument of start_file_write.
    """
    planes: planes_cls = planes_cls
    """
    planes argument of start_file_write.
    """
    op_udf: op_udf_cls = op_udf_cls
    """
    op_udf argument of start_file_write.
    """
    append_sample: append_sample_cls = append_sample_cls
    """
    append_sample argument of start_file_write.
    """
    accumulate_rates: accumulate_rates_cls = accumulate_rates_cls
    """
    accumulate_rates argument of start_file_write.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .a import a as a_cls
from .b import b as b_cls
from .c import c as c_cls
from .d import d as d_cls
from .e import e as e_cls
class gupta_curve_fit_conductivity(Group):
    """
    'gupta_curve_fit_conductivity' child.
    """

    fluent_name = "gupta-curve-fit-conductivity"

    child_names = \
        ['a', 'b', 'c', 'd', 'e']

    a: a_cls = a_cls
    """
    a child of gupta_curve_fit_conductivity.
    """
    b: b_cls = b_cls
    """
    b child of gupta_curve_fit_conductivity.
    """
    c: c_cls = c_cls
    """
    c child of gupta_curve_fit_conductivity.
    """
    d: d_cls = d_cls
    """
    d child of gupta_curve_fit_conductivity.
    """
    e: e_cls = e_cls
    """
    e child of gupta_curve_fit_conductivity.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option_2 import option as option_cls
from .constant_length import constant_length as constant_length_cls
from .variable_length import variable_length as variable_length_cls
class vector_length(Group):
    """
    'vector_length' child.
    """

    fluent_name = "vector-length"

    child_names = \
        ['option', 'constant_length', 'variable_length']

    option: option_cls = option_cls
    """
    option child of vector_length.
    """
    constant_length: constant_length_cls = constant_length_cls
    """
    constant_length child of vector_length.
    """
    variable_length: variable_length_cls = variable_length_cls
    """
    variable_length child of vector_length.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .name import name as name_cls
from .phase_16 import phase as phase_cls
from .geom_disable import geom_disable as geom_disable_cls
from .geom_dir_spec import geom_dir_spec as geom_dir_spec_cls
from .geom_dir_x import geom_dir_x as geom_dir_x_cls
from .geom_dir_y import geom_dir_y as geom_dir_y_cls
from .geom_dir_z import geom_dir_z as geom_dir_z_cls
from .geom_levels import geom_levels as geom_levels_cls
from .geom_bgthread import geom_bgthread as geom_bgthread_cls
from .porous_jump_turb_wall_treatment_1 import porous_jump_turb_wall_treatment as porous_jump_turb_wall_treatment_cls
from .alpha import alpha as alpha_cls
from .dm import dm as dm_cls
from .c2_1 import c2 as c2_cls
from .thermal_ctk import thermal_ctk as thermal_ctk_cls
from .solar_fluxes import solar_fluxes as solar_fluxes_cls
from .v_absp import v_absp as v_absp_cls
from .ir_absp import ir_absp as ir_absp_cls
from .ir_trans import ir_trans as ir_trans_cls
from .v_trans import v_trans as v_trans_cls
from .discrete_phase_bc_type import discrete_phase_bc_type as discrete_phase_bc_type_cls
from .dem_collision_partner import dem_collision_partner as dem_collision_partner_cls
from .reinj_inj import reinj_inj as reinj_inj_cls
from .discrete_phase_bc_function import discrete_phase_bc_function as discrete_phase_bc_function_cls
from .strength import strength as strength_cls
from .jump_adhesion import jump_adhesion as jump_adhesion_cls
from .adhesion_constrained import adhesion_constrained as adhesion_constrained_cls
from .contact_angles import contact_angles as contact_angles_cls
from .x_displacement_type import x_displacement_type as x_displacement_type_cls
from .x_displacement_value import x_displacement_value as x_displacement_value_cls
from .y_displacement_type import y_displacement_type as y_displacement_type_cls
from .y_displacement_value import y_displacement_value as y_displacement_value_cls
from .z_displacement_type import z_displacement_type as z_displacement_type_cls
from .z_displacement_value import z_displacement_value as z_displacement_value_cls
class porous_jump_child(Group):
    """
    'child_object_type' of porous_jump.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['name', 'phase', 'geom_disable', 'geom_dir_spec', 'geom_dir_x',
         'geom_dir_y', 'geom_dir_z', 'geom_levels', 'geom_bgthread',
         'porous_jump_turb_wall_treatment', 'alpha', 'dm', 'c2',
         'thermal_ctk', 'solar_fluxes', 'v_absp', 'ir_absp', 'ir_trans',
         'v_trans', 'discrete_phase_bc_type', 'dem_collision_partner',
         'reinj_inj', 'discrete_phase_bc_function', 'strength',
         'jump_adhesion', 'adhesion_constrained', 'contact_angles',
         'x_displacement_type', 'x_displacement_value', 'y_displacement_type',
         'y_displacement_value', 'z_displacement_type',
         'z_displacement_value']

    name: name_cls = name_cls
    """
    name child of porous_jump_child.
    """
    phase: phase_cls = phase_cls
    """
    phase child of porous_jump_child.
    """
    geom_disable: geom_disable_cls = geom_disable_cls
    """
    geom_disable child of porous_jump_child.
    """
    geom_dir_spec: geom_dir_spec_cls = geom_dir_spec_cls
    """
    geom_dir_spec child of porous_jump_child.
    """
    geom_dir_x: geom_dir_x_cls = geom_dir_x_cls
    """
    geom_dir_x child of porous_jump_child.
    """
    geom_dir_y: geom_dir_y_cls = geom_dir_y_cls
    """
    geom_dir_y child of porous_jump_child.
    """
    geom_dir_z: geom_dir_z_cls = geom_dir_z_cls
    """
    geom_dir_z child of porous_jump_child.
    """
    geom_levels: geom_levels_cls = geom_levels_cls
    """
    geom_levels child of porous_jump_child.
    """
    geom_bgthread: geom_bgthread_cls = geom_bgthread_cls
    """
    geom_bgthread child of porous_jump_child.
    """
    porous_jump_turb_wall_treatment: porous_jump_turb_wall_treatment_cls = porous_jump_turb_wall_treatment_cls
    """
    porous_jump_turb_wall_treatment child of porous_jump_child.
    """
    alpha: alpha_cls = alpha_cls
    """
    alpha child of porous_jump_child.
    """
    dm: dm_cls = dm_cls
    """
    dm child of porous_jump_child.
    """
    c2: c2_cls = c2_cls
    """
    c2 child of porous_jump_child.
    """
    thermal_ctk: thermal_ctk_cls = thermal_ctk_cls
    """
    thermal_ctk child of porous_jump_child.
    """
    solar_fluxes: solar_fluxes_cls = solar_fluxes_cls
    """
    solar_fluxes child of porous_jump_child.
    """
    v_absp: v_absp_cls = v_absp_cls
    """
    v_absp child of porous_jump_child.
    """
    ir_absp: ir_absp_cls = ir_absp_cls
    """
    ir_absp child of porous_jump_child.
    """
    ir_trans: ir_trans_cls = ir_trans_cls
    """
    ir_trans child of porous_jump_child.
    """
    v_trans: v_trans_cls = v_trans_cls
    """
    v_trans child of porous_jump_child.
    """
    discrete_phase_bc_type: discrete_phase_bc_type_cls = discrete_phase_bc_type_cls
    """
    discrete_phase_bc_type child of porous_jump_child.
    """
    dem_collision_partner: dem_collision_partner_cls = dem_collision_partner_cls
    """
    dem_collision_partner child of porous_jump_child.
    """
    reinj_inj: reinj_inj_cls = reinj_inj_cls
    """
    reinj_inj child of porous_jump_child.
    """
    discrete_phase_bc_function: discrete_phase_bc_function_cls = discrete_phase_bc_function_cls
    """
    discrete_phase_bc_function child of porous_jump_child.
    """
    strength: strength_cls = strength_cls
    """
    strength child of porous_jump_child.
    """
    jump_adhesion: jump_adhesion_cls = jump_adhesion_cls
    """
    jump_adhesion child of porous_jump_child.
    """
    adhesion_constrained: adhesion_constrained_cls = adhesion_constrained_cls
    """
    adhesion_constrained child of porous_jump_child.
    """
    contact_angles: contact_angles_cls = contact_angles_cls
    """
    contact_angles child of porous_jump_child.
    """
    x_displacement_type: x_displacement_type_cls = x_displacement_type_cls
    """
    x_displacement_type child of porous_jump_child.
    """
    x_displacement_value: x_displacement_value_cls = x_displacement_value_cls
    """
    x_displacement_value child of porous_jump_child.
    """
    y_displacement_type: y_displacement_type_cls = y_displacement_type_cls
    """
    y_displacement_type child of porous_jump_child.
    """
    y_displacement_value: y_displacement_value_cls = y_displacement_value_cls
    """
    y_displacement_value child of porous_jump_child.
    """
    z_displacement_type: z_displacement_type_cls = z_displacement_type_cls
    """
    z_displacement_type child of porous_jump_child.
    """
    z_displacement_value: z_displacement_value_cls = z_displacement_value_cls
    """
    z_displacement_value child of porous_jump_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .boundary_volume import boundary_volume as boundary_volume_cls
from .volume_growth import volume_growth as volume_growth_cls
class volume_distance(Group):
    """
    'volume_distance' child.
    """

    fluent_name = "volume-distance"

    child_names = \
        ['boundary_volume', 'volume_growth']

    boundary_volume: boundary_volume_cls = boundary_volume_cls
    """
    boundary_volume child of volume_distance.
    """
    volume_growth: volume_growth_cls = volume_growth_cls
    """
    volume_growth child of volume_distance.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .start_keyframe import start_keyframe as start_keyframe_cls
from .end_keyframe import end_keyframe as end_keyframe_cls
from .increment_2 import increment as increment_cls
class set_custom_frames(Group):
    """
    Set custom frames start, end, skip frames for video export.
    """

    fluent_name = "set-custom-frames"

    child_names = \
        ['start_keyframe', 'end_keyframe', 'increment']

    start_keyframe: start_keyframe_cls = start_keyframe_cls
    """
    start_keyframe child of set_custom_frames.
    """
    end_keyframe: end_keyframe_cls = end_keyframe_cls
    """
    end_keyframe child of set_custom_frames.
    """
    increment: increment_cls = increment_cls
    """
    increment child of set_custom_frames.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

class slit_interior_between_diff_solids(Command):
    """
    Slit interior created between different solids into coupled walls.
    """

    fluent_name = "slit-interior-between-diff-solids"




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .reconstruct_geometry import reconstruct_geometry as reconstruct_geometry_cls
class geometry(Group):
    """
    Enter the adaption geometry menu.
    """

    fluent_name = "geometry"

    child_names = \
        ['reconstruct_geometry']

    reconstruct_geometry: reconstruct_geometry_cls = reconstruct_geometry_cls
    """
    reconstruct_geometry child of geometry.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class vector_child:
    fluent_name = ...
    child_names = ...
    name = ...
    field = ...
    vector_field = ...
    surfaces_list = ...
    scale = ...
    style = ...
    skip = ...
    vector_opt = ...
    range_option = ...
    color_map = ...
    draw_mesh = ...
    mesh_object = ...
    display_state_name = ...
    physics = ...
    geometry = ...
    surfaces = ...
    command_names = ...

    def display(self, ):
        """
        'display' command.
        """




#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .mod_name import mod_name as mod_name_cls
class disable_modification(Command):
    """
    Disable a single defined case modification.
    
    Parameters
    ----------
        mod_name : str
            'mod_name' child.
    
    """

    fluent_name = "disable-modification"

    argument_names = \
        ['mod_name']

    mod_name: mod_name_cls = mod_name_cls
    """
    mod_name argument of disable_modification.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .control_time_step_size_variation import control_time_step_size_variation as control_time_step_size_variation_cls
from .use_average_cfl import use_average_cfl as use_average_cfl_cls
from .cfl_type import cfl_type as cfl_type_cls
class cfl_based_time_stepping_advanced_options(Group):
    """
    Advanced settings for CFL-based time stepping.
    """

    fluent_name = "cfl-based-time-stepping-advanced-options"

    child_names = \
        ['control_time_step_size_variation', 'use_average_cfl', 'cfl_type']

    control_time_step_size_variation: control_time_step_size_variation_cls = control_time_step_size_variation_cls
    """
    control_time_step_size_variation child of cfl_based_time_stepping_advanced_options.
    """
    use_average_cfl: use_average_cfl_cls = use_average_cfl_cls
    """
    use_average_cfl child of cfl_based_time_stepping_advanced_options.
    """
    cfl_type: cfl_type_cls = cfl_type_cls
    """
    cfl_type child of cfl_based_time_stepping_advanced_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .from_zone_type_1 import from_zone_type as from_zone_type_cls
from .from_zone_name_1 import from_zone_name as from_zone_name_cls
from .phase_28 import phase as phase_cls
class compute_defaults(Command):
    """
    Compute default values from selection.
    
    Parameters
    ----------
        from_zone_type : str
            Select boundary/zone type.
        from_zone_name : str
            Selecte zone name.
        phase : str
            Select phase name.
    
    """

    fluent_name = "compute-defaults"

    argument_names = \
        ['from_zone_type', 'from_zone_name', 'phase']

    from_zone_type: from_zone_type_cls = from_zone_type_cls
    """
    from_zone_type argument of compute_defaults.
    """
    from_zone_name: from_zone_name_cls = from_zone_name_cls
    """
    from_zone_name argument of compute_defaults.
    """
    phase: phase_cls = phase_cls
    """
    phase argument of compute_defaults.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .register_name import register_name as register_name_cls
class list_properties(Command):
    """
    List the properties of a definition for poor mesh numerics.
    
    Parameters
    ----------
        register_name : str
            'register_name' child.
    
    """

    fluent_name = "list-properties"

    argument_names = \
        ['register_name']

    register_name: register_name_cls = register_name_cls
    """
    register_name argument of list_properties.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .use import use as use_cls
from .user_defined_6 import user_defined as user_defined_cls
from .value_1 import value as value_cls
class vof_free_surface_weight(Group):
    """
    Set VOF free surface weight.
    """

    fluent_name = "vof-free-surface-weight"

    child_names = \
        ['use', 'user_defined', 'value']

    use: use_cls = use_cls
    """
    use child of vof_free_surface_weight.
    """
    user_defined: user_defined_cls = user_defined_cls
    """
    user_defined child of vof_free_surface_weight.
    """
    value: value_cls = value_cls
    """
    value child of vof_free_surface_weight.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .two_stage import two_stage as two_stage_cls
from .default_multi_stage import default_multi_stage as default_multi_stage_cls
class runge_kutta(Group):
    """
    'runge_kutta' child.
    """

    fluent_name = "runge-kutta"

    child_names = \
        ['two_stage', 'default_multi_stage']

    two_stage: two_stage_cls = two_stage_cls
    """
    two_stage child of runge_kutta.
    """
    default_multi_stage: default_multi_stage_cls = default_multi_stage_cls
    """
    default_multi_stage child of runge_kutta.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .fluid_child import fluid_child

class fluid(NamedObject[fluid_child], _CreatableNamedObjectMixin[fluid_child]):
    """
    'fluid' child.
    """

    fluent_name = "fluid"

    child_object_type: fluid_child = fluid_child
    """
    child_object_type of fluid.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .voltage_tap import voltage_tap as voltage_tap_cls
from .current_tap import current_tap as current_tap_cls
from .conductive_regions import conductive_regions as conductive_regions_cls
from .contact_resistance_regions import contact_resistance_regions as contact_resistance_regions_cls
class electric_field(Group):
    """
    'electric_field' child.
    """

    fluent_name = "electric-field"

    child_names = \
        ['voltage_tap', 'current_tap', 'conductive_regions',
         'contact_resistance_regions']

    voltage_tap: voltage_tap_cls = voltage_tap_cls
    """
    voltage_tap child of electric_field.
    """
    current_tap: current_tap_cls = current_tap_cls
    """
    current_tap child of electric_field.
    """
    conductive_regions: conductive_regions_cls = conductive_regions_cls
    """
    conductive_regions child of electric_field.
    """
    contact_resistance_regions: contact_resistance_regions_cls = contact_resistance_regions_cls
    """
    contact_resistance_regions child of electric_field.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .auto_range_1 import auto_range as auto_range_cls
from .correlation import correlation as correlation_cls
from .cumulation_curve import cumulation_curve as cumulation_curve_cls
from .diameter_statistics import diameter_statistics as diameter_statistics_cls
from .histogram_mode import histogram_mode as histogram_mode_cls
from .percentage import percentage as percentage_cls
from .variable_3 import variable_3 as variable_3_cls
from .logarithmic import logarithmic as logarithmic_cls
from .weighting import weighting as weighting_cls
class histogram_options(Group):
    """
    Enter the settings menu for the histogram.
    """

    fluent_name = "histogram-options"

    child_names = \
        ['auto_range', 'correlation', 'cumulation_curve',
         'diameter_statistics', 'histogram_mode', 'percentage', 'variable_3',
         'logarithmic', 'weighting']

    auto_range: auto_range_cls = auto_range_cls
    """
    auto_range child of histogram_options.
    """
    correlation: correlation_cls = correlation_cls
    """
    correlation child of histogram_options.
    """
    cumulation_curve: cumulation_curve_cls = cumulation_curve_cls
    """
    cumulation_curve child of histogram_options.
    """
    diameter_statistics: diameter_statistics_cls = diameter_statistics_cls
    """
    diameter_statistics child of histogram_options.
    """
    histogram_mode: histogram_mode_cls = histogram_mode_cls
    """
    histogram_mode child of histogram_options.
    """
    percentage: percentage_cls = percentage_cls
    """
    percentage child of histogram_options.
    """
    variable_3: variable_3_cls = variable_3_cls
    """
    variable_3 child of histogram_options.
    """
    logarithmic: logarithmic_cls = logarithmic_cls
    """
    logarithmic child of histogram_options.
    """
    weighting: weighting_cls = weighting_cls
    """
    weighting child of histogram_options.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .thickness_1 import thickness as thickness_cls
from .material import material as material_cls
from .qdot import qdot as qdot_cls
class thin_wall_child(Group):
    """
    'child_object_type' of thin_wall.
    """

    fluent_name = "child-object-type"

    child_names = \
        ['thickness', 'material', 'qdot']

    thickness: thickness_cls = thickness_cls
    """
    thickness child of thin_wall_child.
    """
    material: material_cls = material_cls
    """
    material child of thin_wall_child.
    """
    qdot: qdot_cls = qdot_cls
    """
    qdot child of thin_wall_child.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .option_7 import option as option_cls
class pressure_gradient_force(Group):
    """
    'pressure_gradient_force' child.
    """

    fluent_name = "pressure-gradient-force"

    child_names = \
        ['option']

    option: option_cls = option_cls
    """
    option child of pressure_gradient_force.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .local_dt import local_dt as local_dt_cls
from .global_dt import global_dt as global_dt_cls
class pseudo_time_method_usage(Group):
    """
    'pseudo_time_method_usage' child.
    """

    fluent_name = "pseudo-time-method-usage"

    child_names = \
        ['local_dt', 'global_dt']

    local_dt: local_dt_cls = local_dt_cls
    """
    local_dt child of pseudo_time_method_usage.
    """
    global_dt: global_dt_cls = global_dt_cls
    """
    global_dt child of pseudo_time_method_usage.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .list import list as list_cls
from .list_properties import list_properties as list_properties_cls
from .duplicate import duplicate as duplicate_cls
from .display_2 import display as display_cls
from .copy_4 import copy as copy_cls
from .add_to_graphics import add_to_graphics as add_to_graphics_cls
from .clear_history import clear_history as clear_history_cls
from .particle_track_child import particle_track_child

class particle_track(NamedObject[particle_track_child], _CreatableNamedObjectMixin[particle_track_child]):
    """
    'particle_track' child.
    """

    fluent_name = "particle-track"

    command_names = \
        ['list', 'list_properties', 'duplicate', 'display', 'copy',
         'add_to_graphics', 'clear_history']

    list: list_cls = list_cls
    """
    list command of particle_track.
    """
    list_properties: list_properties_cls = list_properties_cls
    """
    list_properties command of particle_track.
    """
    duplicate: duplicate_cls = duplicate_cls
    """
    duplicate command of particle_track.
    """
    display: display_cls = display_cls
    """
    display command of particle_track.
    """
    copy: copy_cls = copy_cls
    """
    copy command of particle_track.
    """
    add_to_graphics: add_to_graphics_cls = add_to_graphics_cls
    """
    add_to_graphics command of particle_track.
    """
    clear_history: clear_history_cls = clear_history_cls
    """
    clear_history command of particle_track.
    """
    child_object_type: particle_track_child = particle_track_child
    """
    child_object_type of particle_track.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .recommended_defaults_for_existing_cases import recommended_defaults_for_existing_cases as recommended_defaults_for_existing_cases_cls
from .revert_to_pre_r20_1_default_settings import revert_to_pre_r20_1_default_settings as revert_to_pre_r20_1_default_settings_cls
class default_controls(Group):
    """
    Multiphase default controls menu.
    """

    fluent_name = "default-controls"

    child_names = \
        ['recommended_defaults_for_existing_cases',
         'revert_to_pre_r20_1_default_settings']

    recommended_defaults_for_existing_cases: recommended_defaults_for_existing_cases_cls = recommended_defaults_for_existing_cases_cls
    """
    recommended_defaults_for_existing_cases child of default_controls.
    """
    revert_to_pre_r20_1_default_settings: revert_to_pre_r20_1_default_settings_cls = revert_to_pre_r20_1_default_settings_cls
    """
    revert_to_pre_r20_1_default_settings child of default_controls.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enable_auto_creation_of_scp_file import enable_auto_creation_of_scp_file as enable_auto_creation_of_scp_file_cls
from .write_sc_file import write_sc_file as write_sc_file_cls
class sc_def_file_settings(Group):
    """
    File menu.
    """

    fluent_name = "sc-def-file-settings"

    child_names = \
        ['enable_auto_creation_of_scp_file']

    enable_auto_creation_of_scp_file: enable_auto_creation_of_scp_file_cls = enable_auto_creation_of_scp_file_cls
    """
    enable_auto_creation_of_scp_file child of sc_def_file_settings.
    """
    command_names = \
        ['write_sc_file']

    write_sc_file: write_sc_file_cls = write_sc_file_cls
    """
    write_sc_file command of sc_def_file_settings.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#

from ansys.fluent.core.solver.flobject import *

from ansys.fluent.core.solver.flobject import _ChildNamedObjectAccessorMixin

from ansys.fluent.core.solver.flobject import _CreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _NonCreatableNamedObjectMixin

from ansys.fluent.core.solver.flobject import _HasAllowedValuesMixin

from .enable_1 import enable as enable_cls
from .disable import disable as disable_cls
from .print import print as print_cls
from .clear import clear as clear_cls
class profile(Group):
    """
    Enter the adaption profile menu.
    """

    fluent_name = "profile"

    command_names = \
        ['enable', 'disable', 'print', 'clear']

    enable: enable_cls = enable_cls
    """
    enable command of profile.
    """
    disable: disable_cls = disable_cls
    """
    disable command of profile.
    """
    print: print_cls = print_cls
    """
    print command of profile.
    """
    clear: clear_cls = clear_cls
    """
    clear command of profile.
    """



#
# This is an auto-generated file.  DO NOT EDIT!
#


from typing import Union, List, Tuple

class unsteady_statistics:
    fluent_name = ...
    command_names = ...

    def sc_enable_sub_stepping_option_per_coupling_step(self, enable_sub_stepping: bool, num_sub_stepping_coupling_itr: int):
        """
        Enable/disable sub stepping option per coupling step.
        
        Parameters
        ----------
            enable_sub_stepping : bool
                Enable or Disable sub stepping options for each coupling  steps.
            num_sub_stepping_coupling_itr : int
                Set the number of substeps for each coupling iterations (default = 1).
        
        """

